import QtQuick 2.2

HMButtonBase {

    id:button

//-----------------------------------------------------------------------------

    property alias text: textControl.text
    property string imageSource: hmStyle.imageButton
    property string imagePressedSource: hmStyle.imagePressedButton
    property alias iconSource: imageIcon.source
    property alias capitalization: textControl.font.capitalization
    property alias fontPixelSize: textControl.font.pixelSize

    signal clicked()
    signal longPressTick()

    states: [
            State {
                name: "enabled"
                PropertyChanges { target: textControl; opacity: 1 }
                PropertyChanges { target: button; opacity: 1 }
            },
            State {
                name: "disabled"
                PropertyChanges { target: button; opacity: 0.5 }
            },
            State {
                name: "pressed"
            }
        ]

//-----------------------------------------------------------------------------

    state: "enabled"


    Image {
        id: imageControl
        anchors.fill: parent
        source: button.state == "pressed" ? button.imagePressedSource : button.imageSource

        Image {
            id: imageIcon
            anchors {
                left: parent.left
                leftMargin: hmStyle.leftContentMargin/2
            }
            y: button.state == "pressed" ? parent.height/2 - hmStyle.iconHeightWidth/2 + 3/2 : parent.height/2 - hmStyle.iconHeightWidth/2
            height: hmStyle.iconHeightWidth
            width: hmStyle.iconHeightWidth
        }

        HMText {
            id: textControl
            color: hmStyle.buttonTextColor
            anchors {
                fill: parent
                topMargin: button.state == "pressed" ? 3 : 0
            }
            horizontalAlignment: Text.AlignHCenter
            verticalAlignment: Text.AlignVCenter
            font {
                pixelSize: hmStyle.buttonFontHeight
                capitalization: Font.AllUppercase
            }
        }


        MouseArea {
            anchors.fill: parent
            onPressed: {
                if(button.state === "enabled")
                {
                    button.state = "pressed"
                }
            }
            onReleased: {
                longPressTimer.stop()
                if(button.state === "pressed")
                {
                    button.state = "enabled"
                }
            }

            onClicked: {
                if(button.state === "enabled") {                    
                    button.clicked()
                    //utility.googleAnalyticsHitAction("HMButton", analyticsName)
                }
            }
            onPressAndHold: {
                longPressTimer.start()
            }

            Timer {
                id: longPressTimer
                interval: 100; repeat: true
                onTriggered: longPressTick()
            }
        }

    }
}
