import QtQuick 2.2
import QtQuick.Layouts 1.1

HMButtonBase {

    id:button

//-----------------------------------------------------------------------------

    property alias textLine1: textControl1.text
    property alias textLine2: textControl2.text
    property string imageSource: hmStyle.imageButton
    property string imagePressedSource: hmStyle.imagePressedButton
    property alias iconSource: imageIcon.source
    property alias dividerSource: imageDivider.source

    signal clicked()

    states: [
            State {
                name: "enabled"
                PropertyChanges { target: textControl1; opacity: 1 }
                PropertyChanges { target: button; opacity: 1 }
            },
            State {
                name: "disabled"
                PropertyChanges { target: button; opacity: 0.5 }
            },
            State {
                name: "pressed"
            }
        ]

//-----------------------------------------------------------------------------

    state: "enabled"

    Image {
        id: imageControl
        anchors.fill: parent
        source: button.state == "pressed" ? button.imagePressedSource : button.imageSource

        Image {
            id: imageIcon
            anchors {
                left: parent.left
                leftMargin: hmStyle.leftContentMargin/2
            }
            y: button.state == "pressed" ? parent.height/2 - hmStyle.iconHeightWidth/2 + 3/2 : parent.height/2 - hmStyle.iconHeightWidth/2

            height: hmStyle.iconHeightWidth
            width: hmStyle.iconHeightWidth
        }

        Image {
            id: imageDivider
            anchors {
                left: imageIcon.right
                leftMargin: hmStyle.leftContentMargin/2
            }
            y: button.state == "pressed" ? parent.height/2 - hmStyle.iconHeightWidth/2 + 3/2 : parent.height/2 - hmStyle.iconHeightWidth/2

            height: hmStyle.iconHeightWidth
        }


        ColumnLayout {
            id: layout
            anchors.left: imageDivider.right
            anchors.leftMargin: hmStyle.leftContentMargin/2
            anchors.top: parent.top
            anchors.topMargin: button.state == "pressed" ? hmStyle.smallButtonTopBottomMargin + 3 : hmStyle.smallButtonTopBottomMargin
            anchors.bottomMargin: hmStyle.smallButtonTopBottomMargin
            anchors.bottom: parent.bottom
            spacing: 0


            HMText {
                id: textControl1
                color: hmStyle.buttonTextColor
                Layout.fillWidth: true
                Layout.fillHeight: true

                font {
                    pixelSize: hmStyle.smallButtonFontHeight
                    capitalization: Font.AllUppercase
                }
            }

            HMText {
                id: textControl2
                color: hmStyle.buttonTextColor
                Layout.fillWidth: true
                Layout.fillHeight: true

                font {
                    pixelSize: hmStyle.smallButtonFontHeight
                    capitalization: Font.AllUppercase
                }
            }

        }


        MouseArea {
            anchors.fill: parent
            onPressed: {
                if(button.state === "enabled")
                {
                    button.state = "pressed"
                }
            }
            onReleased: {
                if(button.state === "pressed")
                {
                    button.state = "enabled"
                }
            }
            onClicked: {
                if(button.state === "enabled") {
                    //utility.googleAnalyticsHitAction("HMButtonSmall", analyticsName)
                    button.clicked()
                }
            }
        }
    }
}
