import QtQuick 2.0
import HookahMixesModels 1.0


Item {

    id: filter

//-----------------------------------------------------------------------------

    property alias captionText: caption.text

    function resetSelection()
    {
        controller.clearSelectedChilds()
        priv.mixesListModel.setFilter(controller.selectedChildren())
    }

    function show() {
        visible = true
    }
    function hide() {
        visible = false;
    }

    QtObject{
        id: priv

        property Component linesModelComponent
        property Component flavorsModelComponent
        property int bookId
        property var mixesListModel
    }

    function initFilterComponents(bookId, linesComponent, flavorsComponent, listModel) {
        if(priv.bookId != bookId ||
                priv.linesModelComponent !== linesComponent ||
                priv.flavorsModelComponent !== flavorsComponent ||
                priv.mixesListModel !== listModel)
        {
            controller.reset();
            priv.bookId = bookId;
            priv.linesModelComponent = linesComponent;
            linesListView.model = linesComponent.createObject(filter, {"bookId":priv.bookId});
            priv.flavorsModelComponent = flavorsComponent;
            priv.mixesListModel = listModel;
        }
    }

//-----------------------------------------------------------------------------

    ControllerExpandableList {
        id: controller
    }


    Component {
        id: flavorsListDelegate

        HMListView{
            id: childsElement

            property int lineId

            spacing: 1

            anchors.left: parent != null ? parent.left : null
            anchors.right: parent != null? parent.right : null
            height: childsElement.count * hmStyle.listItemFlavorHeightInFilter + (childsElement.count-1)

            visible: controller.isGroupExpanded(lineId)
            interactive: false

            model:  {
                if( priv.flavorsModelComponent != null )
                    return priv.flavorsModelComponent.createObject(childsElement, {"bookId":priv.bookId, "lineId":lineId})
                else
                    return null;
            }

            delegate:  flavorDelegate
        }
    }

    Component {
        id: flavorDelegate

        ListItemFlavorInFilter {
            id: childsLayout

            visible: parent.visible
            anchors.left: parent.left
            anchors.right: parent.right

            flavorId: flavorIdField
            colorBlockColor: flavorColorField
            text: flavorNameField

            selected: controller.isChildSelected(flavorId)
            onClicked: {
                if(controller.isChildSelected(flavorId)){
                    controller.deselectChild(flavorId)
                }
                else
                    controller.selectChild(flavorId)

                selected = controller.isChildSelected(flavorId)

                priv.mixesListModel.setFilter(controller.selectedChildren())
            }

            Component.onCompleted: {
                controller.selectedChildsCountChanged.connect(updateSelection);
            }

            function updateSelection() {
                if( controller ) {
                    selected = controller.isChildSelected(flavorId)
                }
            }
        }
    }


    Component {
        id: lineDelegate

        Column {
            id: column
            anchors.left: parent.left
            anchors.right: parent.right
            spacing: 1

            ListItemHeaderInFilter {

                property var childsElementList: null

                id: groupElement
                anchors.left: parent.left
                anchors.right: parent.right

                title: makerNameField
                description: lineNameField
                separatorVisible: true
                state: controller.isGroupExpanded(lineIdField) ? "expanded" : "collapsed"

                onClicked: {

                    if(!childsElementList) {
                        childsElementList = flavorsListDelegate.createObject(column,{"lineId":lineIdField})
                    }

                    childsElementList.visible = !childsElementList.visible
                    if(childsElementList.visible)
                        controller.expandGroup(lineIdField)
                    else
                        controller.collapseGroup(lineIdField)
                }
            }
        }
    }

//-----------------------------------------------------------------------------


    Item {
        id: transparentLeftArea
        anchors.top: parent.top
        anchors.bottom: parent.bottom
        anchors.left: parent.left
        anchors.right: closeArea.left

        MouseArea {
            anchors.fill: parent
        }
    }


    Rectangle {
        id: closeArea

        anchors.right: contentRect.left
        anchors.top: parent.top
        anchors.bottom: parent.bottom
        width: hmStyle.filterCloseBarWidth
        color : hmStyle.filterScreenBackgroundColor
        Rectangle {
            anchors.fill: parent
            opacity: 0.1
        }
        Image{
            id: closeButton
            anchors.verticalCenter: parent.verticalCenter
            anchors.horizontalCenter: parent.horizontalCenter
            width: hmStyle.iconHeightWidth
            height: hmStyle.iconHeightWidth
            source: hmStyle.imageNavBarBack

            rotation: 180
        }

        MouseArea {
            anchors.fill: parent
            onClicked: {
                hide()
            }
        }
    }

    Rectangle {
        id: contentRect
        anchors.top: parent.top
        anchors.bottom: parent.bottom
        anchors.right: parent.right
        width: hmStyle.filterContentWidth
        color: hmStyle.filterScreenBackgroundColor

        Rectangle {
            anchors.fill: parent
            opacity: 0.1
        }

        HMText {
            id: caption

            anchors.top: parent.top
            anchors.left: parent.left
            anchors.leftMargin: hmStyle.leftContentMargin
            anchors.right: parent.right
            font.pixelSize: hmStyle.filterCaptionFontSize
            verticalAlignment: Text.AlignVCenter


            height: hmStyle.navigationBarHeight
        }

        HMSeparator {
            id: separator
            anchors.left: parent.left; anchors.right: parent.right; anchors.top: caption.bottom
        }

        // list of flavors on the shelf
        HMListView {
            id: linesListView
            anchors.left: parent.left
            anchors.right: parent.right
            anchors.top: separator.bottom
            anchors.bottom: clearButton.top
            delegate: lineDelegate 	// Refers to the delegate component
            clip: true
        }

        HMRedButton {
            id: clearButton

            anchors {
                left: parent.left
                right: parent.right
                bottom: parent.bottom
                leftMargin: hmStyle.buttonMargin
                rightMargin: hmStyle.buttonMargin
            }
            height: hmStyle.bottomButtonHeight

            //: Caption of "clear" button on filter control
            text: qsTr("clear-filter-button-caption")
            state: controller.selectedChildsCount > 0 ? "enabled" : "disabled"

            onClicked: {
                resetSelection();
            }
        }
    }
}
