import QtQuick 2.2
import QtQuick.Window 2.1
import QtQuick.Layouts 1.1
import QtGraphicalEffects 1.0

Item {

    id: item

    signal clicked()
    property alias title: titleControl.text
    property alias imageSource: imageControl.source
    property alias separatorVisible: separator.visible
    property bool blinking: false

    readonly property int blinkingInterval: 500
    readonly property double blinkingScale: 1.1

    transform: Scale {
                id: scaleTransform
                origin.x: item.width/2; origin.y: item.height/2
                xScale: mouseArea.pressed ? 1.03 : 1
                yScale: mouseArea.pressed ? 1.03 : 1

                Behavior on xScale {  // for animation
                    NumberAnimation { duration: 100 }
                }
                Behavior on yScale {  // for animation
                    NumberAnimation { duration: 100 }
                }
            }

//-----------------------------------------------------------------------------

    height: hmStyle.listItemHeaderMenuHeight

//-----------------------------------------------------------------------------

    Image {
        id: imageControl
        anchors.left: parent.left
        anchors.verticalCenter: parent.verticalCenter
        fillMode: Image.PreserveAspectFit
        width: hmStyle.mainMenuIconHeightWidth
        height: hmStyle.mainMenuIconHeightWidth

        Timer {
            id: blinkingTimer
            interval: blinkingInterval
            repeat: true
            running: blinking
            onTriggered: {
                blinkingTransform.xScale = blinkingTransform.xScale == 1 ? blinkingScale : 1
                blinkingTransform.yScale = blinkingTransform.yScale == 1 ? blinkingScale : 1
            }
        }

        transform: Scale {
                    id: blinkingTransform
                    origin.x: imageControl.width/2; origin.y: imageControl.height/2
                    //xScale: item.blinking ? 1.3 : 1
                    //yScale: item.blinking ? 1.3 : 1

                    Behavior on xScale {  // for animation
                        NumberAnimation { duration: blinkingInterval }
                    }
                    Behavior on yScale {  // for animation
                        NumberAnimation { duration: blinkingInterval }
                    }
                }

    }

    //title
    HMText {
        id: titleControl
        anchors.left: imageControl.right
        anchors.leftMargin: hmStyle.leftContentMargin
        anchors.top: parent.top
        anchors.bottom: parent.bottom
        font.pixelSize: hmStyle.mainMenuTextFontSize
        verticalAlignment: Text.AlignVCenter
    }


    Rectangle {
        id: separator
        anchors.top: parent.top
        anchors.left: parent.left
        anchors.right: parent.right

        height: 1
        color: hmStyle.listItemSeparatorColor
        opacity: hmStyle.separatorOpacity
        visible: false;
    }

    //sensitive area
    MouseArea {
        id: mouseArea
        anchors.fill: parent
        onClicked: {
            parent.clicked()
        }
    }

//-----------------------------------------------------------------------------

}
