import QtQuick 2.2
import QtQuick.Window 2.1
import QtQuick.Layouts 1.1
import QtGraphicalEffects 1.0

Item {

    id: item

    signal clicked()
    property alias title: titleControl.text
    property alias description: descriptionControl.text
    property alias imageSource: imageControl.source
    property alias separatorVisible: separator.visible
    property bool locked: false
    property bool showLoading: false


    transform: Scale {
                id: scaleTransform
                origin.x: item.width/2; origin.y: item.height/2
                xScale: mouseArea.pressed ? 1.02 : 1
                yScale: mouseArea.pressed ? 1.02 : 1

                Behavior on xScale {  // for animation
                    NumberAnimation { duration: 100 }
                }
                Behavior on yScale {  // for animation
                    NumberAnimation { duration: 100 }
                }
            }

//-----------------------------------------------------------------------------

    height: hmStyle.listItemMenuHeight

//-----------------------------------------------------------------------------

    Image {
        id: imageControl
        anchors.left: parent.left
        anchors.verticalCenter: parent.verticalCenter
        width: hmStyle.menuIconHeightWidth
        height: hmStyle.menuIconHeightWidth

        Image {
            anchors.fill: parent
            visible: item.locked
            enabled: visible
            source: "qrc:/images/locked.png"
        }

        Image {
            height: hmStyle.loadingIconHeight
            width: hmStyle.loadingIconHeight
            anchors.centerIn: parent
            visible: showLoading ? imageControl.status == Image.Loading || imageControl.status == Image.Null : false
            source: "qrc:/images/loading.png"
            asynchronous: true

            RotationAnimator on rotation {
                from: 0;
                to: 360;
                duration: 1000
                running: true
                onRunningChanged: {running = true;}
            }
       }
    }


    Item {
        anchors {
           verticalCenter: parent.verticalCenter
           left: imageControl.right
           leftMargin: hmStyle.leftContentMargin
           right: parent.right
        }
        height: titleControl.height + descriptionControl.height


        //title
        HMText {
            id: titleControl
            anchors.left: parent.left
            anchors.right: parent.right
            font.pixelSize: hmStyle.listItemHeaderMenuTextFontSize
            verticalAlignment: Text.AlignVCenter
            font.capitalization: Font.AllUppercase
            wrapMode: Text.Wrap
        }

        //description
        HMText {
            id: descriptionControl
            anchors.top: titleControl.bottom
            anchors.left: parent.left
            anchors.right: parent.right
            verticalAlignment: Text.AlignVCenter
            font.pixelSize: hmStyle.listItemMenuDescriptionFontSize
            wrapMode: Text.Wrap
        }
    }


    Rectangle {
        id: separator
        anchors.top: parent.top
        anchors.left: parent.left
        anchors.right: parent.right

        height: 1
        color: hmStyle.listItemSeparatorColor
        opacity: hmStyle.separatorOpacity
        visible: false;
    }

    //sensitive area
    MouseArea {
        id: mouseArea
        anchors.fill: parent
        onClicked: {
            parent.clicked()
        }
    }

//-----------------------------------------------------------------------------

}

