import QtQuick 2.2
import QtQuick.Window 2.1
import QtQuick.Layouts 1.1
import QtGraphicalEffects 1.0

Item {

    id: item

    signal clicked()
    property alias title: titleControl.text
    property alias description: descriptionControl.text
    property alias separatorVisible: separator.visible

    transform: Scale {
                id: scaleTransform
                origin.x: item.width/2; origin.y: item.height/2
                xScale: mouseArea.pressed ? 1.02 : 1
                yScale: mouseArea.pressed ? 1.02 : 1

                Behavior on xScale {  // for animation
                    NumberAnimation { duration: 100 }
                }
                Behavior on yScale {  // for animation
                    NumberAnimation { duration: 100 }
                }
            }

//-----------------------------------------------------------------------------

    height: hmStyle.listItemHeaderMenuHeight
    state: "collapsed"

//-----------------------------------------------------------------------------

    states: [
            State {
                name: "expanded"
                PropertyChanges { target: image; source: hmStyle.imageArrowUp }
            },
            State {
                name: "collapsed"
                PropertyChanges { target: image; source: hmStyle.imageArrowDown }
            }
        ]

    //-----------------------------------------------------------------------------

    Item {
        anchors {
           verticalCenter: parent.verticalCenter
           left: parent.left
           leftMargin: hmStyle.leftContentMargin
           right: parent.right
        }
        height: titleControl.height + descriptionControl.height


        //title
        HMText {
            id: titleControl
            anchors.left: parent.left
            anchors.right: parent.right
            font.pixelSize: hmStyle.listItemHeaderMainMenuTextFontSize
            verticalAlignment: Text.AlignVCenter
            horizontalAlignment: Text.AlignHCenter
            font.capitalization: Font.AllUppercase
        }

        //description
        HMText {
            id: descriptionControl
            anchors.top: titleControl.bottom
            anchors.left: parent.left
            anchors.right: parent.right
            verticalAlignment: Text.AlignVCenter
            horizontalAlignment: Text.AlignHCenter
            font.pixelSize: hmStyle.listItemMainMenuDescriptionFontSize
            font.capitalization: Font.AllUppercase
        }
    }

    Rectangle {
        id: separator
        anchors.top: parent.top
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.leftMargin: hmStyle.leftContentMargin
        anchors.rightMargin: hmStyle.rightContentMargin

        height: 1
        color: hmStyle.listItemSeparatorColor
        opacity: hmStyle.separatorOpacity
        visible: false;
    }

    Image {
        id: image
        anchors.right: parent.right
        anchors.rightMargin: hmStyle.rightContentMargin
        anchors.verticalCenter: parent.verticalCenter
        height: hmStyle.iconHeightWidth
        width: hmStyle.iconHeightWidth
    }

//-----------------------------------------------------------------------------


    //sensitive area
    MouseArea {
        id: mouseArea
        anchors.fill: parent
        onClicked: {
            if(item.state=="collapsed")
                item.state = "expanded"
            else
                item.state = "collapsed"

            parent.clicked()
        }
    }

}
