import QtQuick 2.2
import QtQuick.Window 2.1
import QtQuick.Layouts 1.1
import QtGraphicalEffects 1.0

Item {

    id: item

    signal clicked()
    property string title
    property string description
    property alias separatorVisible: separator.visible

    transform: Scale {
                id: scaleTransform
                origin.x: item.width/2; origin.y: item.height/2
                xScale: mouseArea.pressed ? 1.02 : 1
                yScale: mouseArea.pressed ? 1.02 : 1

                Behavior on xScale {  // for animation
                    NumberAnimation { duration: 100 }
                }
                Behavior on yScale {  // for animation
                    NumberAnimation { duration: 100 }
                }
            }

//-----------------------------------------------------------------------------

    height: hmStyle.listItemHeaderMenuHeightInFilter
    state: "collapsed"

//-----------------------------------------------------------------------------

    states: [
            State {
                name: "expanded"
                PropertyChanges { target: image; source: hmStyle.imageArrowUp }
            },
            State {
                name: "collapsed"
                PropertyChanges { target: image; source: hmStyle.imageArrowDown }
            }
        ]

    //-----------------------------------------------------------------------------

    //title
    HMText {
        id: titleControl
        text: title + " " + description
        anchors.left: parent.left
        anchors.leftMargin: hmStyle.leftContentMargin
        anchors.right: parent.right
        font.pixelSize: hmStyle.listItemHeaderMenuInFilterTextFontSize
        verticalAlignment: Text.AlignVCenter
        height: parent.height - separator.height
    }

    Rectangle {
        id: separator
        anchors.top: parent.top
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.leftMargin: hmStyle.leftContentMargin
        anchors.rightMargin: hmStyle.rightContentMargin

        height: 1
        color: hmStyle.listItemSeparatorColor
        opacity: hmStyle.separatorOpacity
        visible: false;
    }

    Image {
        id: image
        anchors.right: parent.right
        anchors.rightMargin: hmStyle.rightContentMargin
        anchors.verticalCenter: parent.verticalCenter
        height: hmStyle.iconHeightWidthInFilter
        width: hmStyle.iconHeightWidthInFilter
    }

//-----------------------------------------------------------------------------


    //sensitive area
    MouseArea {
        id: mouseArea
        anchors.fill: parent
        onReleased: {
            if (mouse.button == Qt.LeftButton) {
                if(item.state=="collapsed")
                    item.state = "expanded"
                else
                    item.state = "collapsed"

                parent.clicked()
            }
        }
    }

}
