import QtQuick 2.2
import QtQuick.Layouts 1.1
import QtQuick.Controls 1.1
import HookahMixesModels 1.0

ColumnLayout {

    id: recipe
//-----------------------------------------------------------------------------

    property int mixId
    property bool createTextDescriptionForMix : false
    property string mixDescription    

    function update() {
        proportions.clear()
        dbModelMixIngredients.updateData()
    }

    QtObject{
        id: priv

        property var ingredientsList: new Array()

        function recreateMixDescription() {
            mixDescription = "";
            var i=0;
            for(i; i<ingredientsList.length; ++i) {
                mixDescription += ingredientsList[i].tobaccoAmount + " "
                                 + ingredientsList[i].tobaccoFlavorName +
                                " (" + ingredientsList[i].tobaccoMakerName + " " + ingredientsList[i].tobaccoLineName
                                + ")";
                if(i != ingredientsList.length-1) {
                    mixDescription += " + "
                }
            }
        }

        function recalculateProportions(){
            var totalPartsCount = 0
            var sum = 0
            for(var i=0; i<proportions.count; ++i) {
                totalPartsCount += proportions.get(i).amount
            }
            var multiplier = 100/totalPartsCount
            for(var i=0; i<proportions.count; ++i) {
                proportions.get(i).recalculated = Math.floor(proportions.get(i).amount*multiplier)
                sum +=proportions.get(i).recalculated
            }
            proportions.get(proportions.count-1).recalculated += (100-sum)
        }
    }

//-----------------------------------------------------------------------------

    //positioning
    height: rootItem.height


//-----------------------------------------------------------------------------

    ListModel {id: proportions}

    DBModelMixIngredients {
        id: dbModelMixIngredients
        mixId: recipe.mixId
    }

//-----------------------------------------------------------------------------

    Item {

        id: rootItem

        height: recipeListView.height
        anchors.left: parent.left
        anchors.right: parent.right

        ListView{
            id: recipeListView

            model: dbModelMixIngredients
            delegate: delegate 	// Refers to the delegate component

            //positioning
            height: hmStyle.mixIngredientHeight * recipeListView.count
            anchors.left: parent.left
            anchors.right: parent.right
            anchors.top: parent.top
            interactive: false

            Component {
                id: delegate

                Item {
                    id: ingredientItem

                    property alias tobaccoAmount: textCircle.text
                    property string tobaccoFlavorName: flavorName
                    property string tobaccoLineName: lineName
                    property string tobaccoMakerName: makerName

                    height: hmStyle.mixIngredientHeight
                    width: recipe.width

                    Component.onCompleted: {
                        if(createTextDescriptionForMix) {
                            priv.ingredientsList.push(ingredientItem)
                        }
                        proportions.append( {'amount': amount, 'recalculated': 0} )
                        priv.recalculateProportions();
                        textCircle.value = Qt.binding(function() { return proportions.get(index).recalculated })
                    }

                    RowLayout {
                        anchors.fill: parent
                        z: 1

                        HMFlavorCircle {
                            id: colorCircle
                            circleColor: flavorColor
                        }

                        ColumnLayout {

                            HMText {
                                text: makerName + " " +lineName
                                Layout.fillWidth: true
                                font.pixelSize: hmStyle.mixIngredientLineFontSize
                            }
                            HMText {
                                text: flavorName
                                Layout.fillWidth: true
                                font.pixelSize: hmStyle.mixIngredientFlavorFontSize
                            }

                            Layout.fillWidth: true
                            Layout.fillHeight: true
                        }

                        HMTextCircle {
                            id: textCircle
                            text: value + "%"
                            circleColor: flavorColor
                            onTextChanged: {
                                if(createTextDescriptionForMix)
                                    priv.recreateMixDescription()
                            }
                        }

                    }
                }
            }
        }

        MouseArea {
            anchors.fill: parent
        }
    }


//-----------------------------------------------------------------------------

}


//-----------------------------------------------------------------------------
