import QtQuick 2.2
import QtQuick.Layouts 1.1
import HookahMixesModels 1.0

ScreenBase {

    //: about screen title
    screenTitle: qsTr("about-screen-title")
    screenName: "ScreenAbout";

    function update(){
    }

    //-----------------------------------------------------------------------------

    Flickable {
        id: flickable
        anchors.top: parent.top
        anchors.bottom: button.top
        anchors.left: parent.left
        anchors.right: parent.right

        contentWidth: parent.width
        contentHeight: spacer.height + imageControl.height + hookahGustoText.height +  mobileAppText.height + 3*hmStyle.leftContentMargin
        clip: true

        Item {
            id: spacer
            anchors.top: parent.top
            anchors.left: parent.left
            anchors.right: parent.right
            height: 2*hmStyle.leftContentMargin

        }

        Image {
            id: imageControl
            anchors.top: spacer.bottom
            anchors.topMargin: 2*hmStyle.leftContentMargin
            anchors.horizontalCenter: parent.horizontalCenter
            width: hmStyle.imageHookahGustoAboutHeight
            height: hmStyle.imageHookahGustoAboutHeight
            source: hmStyle.imageHookahGustoAbout

            MouseArea {
                anchors.fill: parent
                onClicked: {
                    utility.openOfficialSite();
                }
            }
        }

        HMText {
            id: hookahGustoText
            anchors.top: imageControl.bottom
            anchors.topMargin: hmStyle.leftContentMargin
            anchors.horizontalCenter: parent.horizontalCenter
            text: "HookahGusto 2.5"
            font.pixelSize: hmStyle.aboutTextSize1
        }

        HMText {
            id: mobileAppText
            anchors.top: hookahGustoText.bottom
            anchors.horizontalCenter: parent.horizontalCenter
            //: text that shows that hookahgusto is "mobile app"
            text: qsTr("mobile-app")
            font.pixelSize: hmStyle.aboutTextSize2
        }
    }

    HMButton {
        id: button
        anchors {
            bottom: buttonShare.top
            bottomMargin: hmStyle.leftContentMargin
            left: parent.left
            right: parent.right
            leftMargin: hmStyle.buttonMargin
            rightMargin: hmStyle.buttonMargin
        }
        //: Text for button, that links to official hookahgusto site (hookahgusto.com/ru)
        text: qsTr("hg-offsite-button-text")
        height: hmStyle.bottomButtonHeight

        onClicked: {
            utility.openOfficialSite();
        }
    }

    HMButton {
        id: buttonShare
        anchors {
            bottom: socialIcons.top
            bottomMargin: hmStyle.leftContentMargin
            left: parent.left
            right: parent.right
            leftMargin: hmStyle.buttonMargin
            rightMargin: hmStyle.buttonMargin
        }
        //: Text for button, that links to official hookahgusto site (hookahgusto.com/ru)
        text: qsTr("hg-share-button-text")
        height: hmStyle.bottomButtonHeight

        onClicked: {
            screensStack.openScreen(Qt.resolvedUrl("ScreenShare.qml"), {"shareType": ISharer.TellAboutHookahGusto, "unlock": !settings.isProUnlocked() });
        }
    }

    Row {
        id: socialIcons

        anchors.bottom: aboutText.top
        anchors.bottomMargin: 2*hmStyle.leftContentMargin
        anchors.left: parent.left
        anchors.right: parent.right

        height: hmStyle.imageSmallSocialIconsHeight
        spacing: 0


        HMSocialImage {
            width: socialIcons.width/4
            source: hmStyle.imageVkSmallIcon
            onClicked: {
                utility.openOfficialVk();
            }
        }
        HMSocialImage {
            width: socialIcons.width/4
            source: hmStyle.imageFbSmallIcon
            onClicked: {
                utility.openOfficialFb();
            }
        }
        HMSocialImage {
            width: socialIcons.width/4
            source: hmStyle.imageTwSmallIcon
            onClicked: {
                utility.openOfficialTw();
            }
        }
        HMSocialImage {
            width: socialIcons.width/4
            source: hmStyle.imageInstSmallIcon
            onClicked: {
                utility.openOfficialInst();
            }
        }
    }

    HMText {
        id: aboutText
        anchors.bottom: parent.bottom
        anchors.bottomMargin: 2*hmStyle.leftContentMargin
        anchors.horizontalCenter: parent.horizontalCenter
        //: Text, that links to developer page (Developed by <font color=\"yellow\">Volodymyr Kozieiev</font>)
        text: qsTr("developed-by-text")
        font.pixelSize: hmStyle.aboutTextSize3

        MouseArea {
            anchors.fill: parent
            onClicked: {
                utility.openOfficialDeveloperPage();
            }
        }
    }


    //-----------------------------------------------------------------------------
}
