import QtQuick 2.2
import QtQuick.Layouts 1.1
import HookahMixesModels 1.0

ScreenBase {

    //: about screen title
    screenTitle: aboutScreenTitle

    //-----------------------------------------------------------------------------

    property string aboutImage
    property string aboutTitle
    property string aboutDescription
    property string buttonText
    property string buttonUrl
    property string vkUrl: ""
    property string fbUrl: ""
    property string twUrl: ""
    property string instUrl: ""
    property int socialIconsCount: 4
    property string aboutScreenTitle

    //-----------------------------------------------------------------------------

    function update(){
    }

    //-----------------------------------------------------------------------------



    Flickable {
        id: flickable
        anchors.top: parent.top
        anchors.bottom: button.top
        anchors.left: parent.left
        anchors.right: parent.right

        contentWidth: parent.width
        contentHeight: spacer.height + imageControl.height + doobaccoText.height + text.height + 3*hmStyle.leftContentMargin
        clip: true

        Item {
            id: spacer
            anchors.top: parent.top
            anchors.left: parent.left
            anchors.right: parent.right
            height: hmStyle.leftContentMargin

        }

        Image {
            id: imageControl
            anchors.top: spacer.bottom
            anchors.topMargin: 2*hmStyle.leftContentMargin
            anchors.horizontalCenter: parent.horizontalCenter
            width: hmStyle.imageAboutHeight
            height: hmStyle.imageAboutHeight
            source: aboutImage

            MouseArea {
                anchors.fill: parent
                onClicked: {
                    utility.openUrl(buttonUrl);
                }
            }
        }

        HMText {
            id: doobaccoText
            anchors.top: imageControl.bottom
            anchors.topMargin: hmStyle.leftContentMargin
            anchors.horizontalCenter: parent.horizontalCenter
            text: aboutTitle
            font.pixelSize: hmStyle.aboutTextSize1
        }

        HMText {
            id: text
            property var obj;

            font.pixelSize: hmStyle.tutorialsFontSize

            horizontalAlignment: Text.AlignJustify

            anchors {
                top: doobaccoText.bottom
                left: parent.left
                right: parent.right
                leftMargin: hmStyle.tutorialsLeftRightMargin
                rightMargin: hmStyle.tutorialsLeftRightMargin
            }
            text: aboutDescription
            wrapMode: Text.Wrap
        }

    }

    HMButton {
        id: button
        anchors {
            bottom: socialIcons.top
            bottomMargin: hmStyle.leftContentMargin
            left: parent.left
            right: parent.right
            leftMargin: hmStyle.buttonMargin
            rightMargin: hmStyle.buttonMargin
        }
        //: Text for button, that links to official hookahgusto site (hookahgusto.com/ru)
        text: buttonText
        height: hmStyle.bottomButtonHeight

        onClicked: {
            utility.openUrl(buttonUrl);
        }
    }



    Row {
        id: socialIcons

        anchors.bottom: parent.bottom
        anchors.bottomMargin: hmStyle.leftContentMargin
        anchors.left: parent.left
        anchors.right: parent.right

        height: hmStyle.imageSmallSocialIconsHeight
        spacing: 0

        HMSocialImage {
            width: vkUrl != "" ? socialIcons.width/socialIconsCount : 0
            visible: vkUrl != ""
            source: hmStyle.imageVkSmallIcon
            onClicked: {
                utility.openUrl(vkUrl);
            }
        }
        HMSocialImage {
            width: fbUrl != "" ? socialIcons.width/socialIconsCount : 0
            visible: fbUrl != ""
            source: hmStyle.imageFbSmallIcon
            onClicked: {
                utility.openUrl(fbUrl);
            }
        }
        HMSocialImage {
            width: twUrl != "" ? socialIcons.width/socialIconsCount : 0
            visible: twUrl != ""
            source: hmStyle.imageTwSmallIcon
            onClicked: {
                utility.openUrl(twUrl);
            }
        }
        HMSocialImage {
            width: instUrl != "" ? socialIcons.width/socialIconsCount : 0
            visible: instUrl != ""
            source: hmStyle.imageInstSmallIcon
            onClicked: {
                utility.openUrl(instUrl);
            }
        }
    }

    //-----------------------------------------------------------------------------
}
