import QtQuick 2.2
import QtQuick.Controls 1.1
import HookahMixesModels 1.0
import QtQuick.Layouts 1.1


ScreenBase {
    id: screen

    screenName: "ScreenAddFlavors";
    //: "Add flavors" screen title
    screenTitle: qsTr("add-flavors-screen-title")

    property string maker
    property var functorToCallOnAdd
    property string addFlavorsButtonText

    function update() {
    }

    //controller
    ControllerExpandableList {
        id: controller
    }

    //model
    DBModelLinesForMaker {
        id: dbModelAllLines
        makerName: screen.maker
    }

//-----------------------------------------------------------------------------

    Component {
        id: delegate

        Column {            

            anchors.left: parent.left
            anchors.right: parent.right
            spacing: 1

            ListItemHeader {
                id: groupElement
                anchors.left: parent.left
                anchors.right: parent.right

                title: makerNameField
                description: lineNameField
                separatorVisible: true
                state: controller.isGroupExpanded(lineIdField) ? "expanded" : "collapsed"

                onClicked: {
                    childsElement.visible = !childsElement.visible
                    if(childsElement.visible)
                        controller.expandGroup(lineIdField)
                    else
                        controller.collapseGroup(lineIdField)
                }
            }

            ListView{
                id: childsElement                

                spacing: 1

                anchors.left: parent.left
                anchors.right: parent.right
                height: childsElement.count*hmStyle.listItemFlavorHeight + (childsElement.count-1)

                visible: controller.isGroupExpanded(lineIdField)
                interactive: false

                model: DBModelFlavorsForLine {
                    id: dbModelFlavorsForLine
                    lineId: lineIdField
                }

                delegate: ListItemFlavor {
                    id: childsLayout

                    visible: childsElement.visible
                    anchors.left: parent.left
                    anchors.right: parent.right

                    flavorId: flavorIdField
                    colorBlockColor: flavorColorField
                    text: flavorNameField

                    selected: controller.isChildSelected(flavorId)


                    onClicked: {
                        if(controller.isChildSelected(flavorId)){
                            controller.deselectChild(flavorId)
                        }
                        else
                            controller.selectChild(flavorId)

                        selected = controller.isChildSelected(flavorId)
                    }

                }
            }
        }
    }

//-----------------------------------------------------------------------------

    ColumnLayout {
        anchors.fill: parent

        // list of flavors on the shelf
        HMListView {
            Layout.fillWidth: true
            Layout.fillHeight: true
            model: dbModelAllLines
            delegate: delegate 	// Refers to the delegate component
            clip: true
        }

        Item {
            height: hmStyle.bottomButtonHeight + hmStyle.buttonMargin
            Layout.fillWidth: true

            HMButton {
                id: addButton

                height: hmStyle.bottomButtonHeight
                anchors.left: parent.left
                anchors.right: parent.right
                anchors.bottom: parent.bottom
                anchors.leftMargin: hmStyle.buttonMargin
                anchors.rightMargin: hmStyle.buttonMargin
                anchors.bottomMargin: hmStyle.buttonMargin

                text: addFlavorsButtonText
                iconSource: hmStyle.addButtonIcon

                onClicked: {
                    utility.googleAnalyticsHitAction("functionality", "addFlavors")
                    functorToCallOnAdd.addFlavors(controller.selectedChildren())
                    screensStack.closeScreen();
                }
            }
        }
    }

}
