import QtQuick 2.2
import HookahMixesModels 1.0

ScreenBase {

    id: screen

    screenName: "ScreenBooks";
    // "Books" screen title
    screenTitle: qsTr("books-screen-title")

    function update(){
        dbModelBooksList.updateData();
    }

    signal updateLock();

    //-----------------------------------------------------------------------------

    // Define a delegate component.  A delegate will be
    // instantiated for each visible item in the list.
    Component {
        id: delegate

        HMMenuItem {
            id: listItem
            property int savedBookId: bookId;
            property string bookAboutPage: utility.getBookAboutPage(bookId);

            anchors {
                left: parent.left
                right: parent.right
                leftMargin: hmStyle.menuItemLeftRightMargin
                rightMargin: hmStyle.menuItemLeftRightMargin
            }

            imageSource: utility.bookIconById(savedBookId)
            title: bookName
            //: text under each book: "recipes: "
            description: qsTr("recipes-text") + ": " + (mixesCount == "" ? 0 : mixesCount)
            separatorVisible: true

            locked: utility.isBookLocked(bookId)

            onClicked: {
                if(!listItem.locked) {
                    screensStack.openScreen(Qt.resolvedUrl("ScreenMixesList.qml"), {"bookId": savedBookId, "aboutScreen": bookAboutPage, immediate: true });
                } else {
                    screensStack.openScreen(Qt.resolvedUrl("ScreenUnlock.qml"));
                }

            }

            function changeLock() {
                locked = utility.isBookLocked(bookId)
            }
            Component.onCompleted: {
                changeLock()
            }
        }
    }

    DBModelBooksList {
        id: dbModelBooksList
    }

//-----------------------------------------------------------------------------

    // The actual list
    HMListView {
        clip: true
        id: listControl
        anchors.fill: parent
        model: dbModelBooksList
        delegate: delegate 	// Refers to the delegate component
    }

//-----------------------------------------------------------------------------
}
