import QtQuick 2.2
import QtQuick.Layouts 1.1
import QtQuick.Controls 1.1
import HookahMixesModels 1.0


//-----------------------------------------------------------------------------

ScreenBase {

    id: screen

    property int mixId: -1
    property bool ingredientsListEmtpy: ingredientsModel.count <= 0
    //: "BACK TO MIX" button text
    property string backButtonText : qsTr("back-to-new-mix-text")
    //: Text on the button that adds flavors to the new mix "Add to the mix"
    property string addFlavorsButtonText: qsTr("add-to-mix-button-text")

    screenName: "ScreenEditMix";
    //: Title of "Edit mix" screen ("Edit mix")
    screenTitle: qsTr("edit-mix-screen-title")

    function openItemEditing(itemIndex) {
        editItem.flavorIndex = itemIndex
        editItem.flavorObject = ingredientsModel.get(editItem.flavorIndex)
        editItem.visible = true
    }
    function closeItemEditing() {
        editItem.visible = false
    }

    function processBackPress(){
        if(editItem.visible)
        {
            closeItemEditing()
            return true; //backPress processed
        }
        return false;
    }
    function removeIngredientFromMix(itemIndex) {
        ingredientsModel.remove(itemIndex)
    }

    Component.onCompleted: {
        if(mixId != -1) {
            console.log("dbModelMixIngredients.count", dbModelMixIngredients.rowCount())
            for(var i=0; i<dbModelMixIngredients.rowCount(); ++i) {
                var flavorObj = dbModelMixIngredients.flavorInRow(i)
                ingredientsModel.append({"flavorName":flavorObj.flavorName,
                                          "flavorColor":flavorObj.flavorColor,
                                          "makerName":flavorObj.makerName,
                                          "lineName":flavorObj.lineName,
                                          "flavorAmount": flavorObj.flavorAmount,
                                          "flavorId":flavorObj.flavorId})
            }
        }
    }

    DBModelMixIngredients {
        id: dbModelMixIngredients
        mixId: screen.mixId
    }

    Item {
        id: addFlavorsFunctor
        function addFlavors(flavorsList) {
            var ix = 0
            for(ix; ix<flavorsList.length; ++ix) {
                var yx = 0
                var duplicate = false;
                for(yx; yx<ingredientsModel.count; ++yx) {
                    if(ingredientsModel.get(yx).flavorId == flavorsList[ix]) {
                        duplicate = true
                    }
                }

                if(duplicate) {
                    continue
                }

                var flavorObj = databaseWriter.flavorById(flavorsList[ix])
                ingredientsModel.append({"flavorName":flavorObj.flavorName,
                                          "flavorColor":flavorObj.flavorColor,
                                          "makerName":flavorObj.makerName,
                                          "lineName":flavorObj.lineName,
                                          "flavorAmount" : 34,
                                          "flavorId":flavorsList[ix]})
            }
        }
    }
    function openSelectFlavorsWindow() {
        screensStack.openScreen(Qt.resolvedUrl("ScreenSelectBrand.qml"), {"functorToCallOnAdd":addFlavorsFunctor, "backButtonText":backButtonText, "addFlavorsButtonText":addFlavorsButtonText});
    }

//-----------------------------------------------------------------------------


    HMButtonAdd {
        id: addFirstIngredient
        visible: ingredientsListEmtpy
        //: "Add first ingredient" text
        firstLineText: qsTr("add-first-ingredient")
        onClicked: {
            openSelectFlavorsWindow()
        }
    }


    ListModel {
        id: ingredientsModel
    }

    HMListView {
        id: ingredientsListView

        anchors {
            left: parent.left
            right: parent.right
            top: parent.top
        }
        delegate: delegate
        height: hmStyle.mixIngredientHeight * ingredientsListView.count + hmStyle.bottomButtonHeight
        model: ingredientsModel

        Component {
            id: delegate

            Item {
                id: delegateRootItem
                height: hmStyle.mixIngredientHeight
                width: screen.width

                ColumnLayout {
                    anchors.fill: parent
                    RowLayout {
                        anchors{
                            left: parent.left
                            right: parent.right
                        }
                        z: 1
                        HMFlavorCircle {
                            id: colorCircle
                            circleColor: flavorColor
                        }
                        ColumnLayout {

                            HMText {
                                text: makerName + " " +lineName
                                Layout.fillWidth: true
                                font.pixelSize: hmStyle.mixIngredientLineFontSize
                            }
                            HMText {
                                text: flavorName
                                Layout.fillWidth: true
                                font.pixelSize: hmStyle.mixIngredientFlavorFontSize
                            }

                            Layout.fillWidth: true
                            Layout.fillHeight: true
                        }

                        HMTextCircle {
                            id: textCircle
                            value: flavorAmount
                            text: value + "%"
                            circleColor: flavorColor
                        }
                    }
                }

                MouseArea {
                    anchors.fill: parent
                    onClicked: {
                        openItemEditing(index)
                    }
                }
            }
        }
    }


    HMButton {
        id: addMoreIngredients
        //: "Add ingredients" button text
        text: qsTr("add-ingredients-to-mix")
        height: hmStyle.bottomButtonHeight
        visible: !ingredientsListEmtpy
        anchors {
            left: parent.left
            right: parent.right
            leftMargin: hmStyle.buttonMargin
            rightMargin: hmStyle.buttonMargin
            bottom: buttonsRow.top
            bottomMargin: hmStyle.buttonMargin
        }
        onClicked: openSelectFlavorsWindow()
    }


    Item {
        id: buttonsRow

        height: hmStyle.bottomButtonHeight
        anchors {
            bottom: parent.bottom
            left: parent.left
            right: parent.right
            leftMargin: hmStyle.buttonMargin
            rightMargin: hmStyle.buttonMargin
        }

        HMButton {
            id: saveButton
            anchors.rightMargin: hmStyle.buttonMargin / 2
            enabled: !ingredientsListEmtpy
            visible: !ingredientsListEmtpy
            height: parent.height
            width: parent.width / 2
            //: "SAVE" button on edit mix screen
            text: qsTr("save-edit-mix-button-text")

            onClicked: {
                for(var i=0; i<ingredientsModel.count; ++i){
                    databaseWriter.addUserMixIngredient( ingredientsModel.get(i).flavorId, ingredientsModel.get(i).flavorAmount )
                }
                if(mixId != -1) {
                    databaseWriter.editUserMix(mixId)
                } else {
                    databaseWriter.addUserMix();
                }
                screensStack.closeScreen();
            }
        }

        HMRedButton {
            id: cancelButton
            height: parent.height
            width: ingredientsListEmtpy ? parent.width : parent.width / 2
            anchors.left: ingredientsListEmtpy ? parent.left : saveButton.right
            anchors.leftMargin: ingredientsListEmtpy ? 0 : hmStyle.buttonMargin / 2
            //: "CANCEL" button on edit mix screen
            text: qsTr("cancel-edit-mix-button-text")
            onClicked: screensStack.closeScreen();
        }
    }


    Image {
        source: hmStyle.imageBackground
        id: editItem
        property int flavorIndex: 0
        property var flavorObject: null
        visible: false
        anchors.fill: parent

        Item {

            anchors.centerIn: parent
            anchors.fill: parent

            HMText {
                id: makerNameText
                text: editItem.flavorObject ? editItem.flavorObject.makerName + " " + editItem.flavorObject.lineName : ""
                font.pixelSize: hmStyle.mixIngredientLineFontSize * 1.5
                anchors.bottom: flavorNameText.top
                anchors.horizontalCenter: parent.horizontalCenter
            }
            HMText {
                id: flavorNameText
                text: editItem.flavorObject ? editItem.flavorObject.flavorName : ""
                font.pixelSize: hmStyle.mixIngredientFlavorFontSize * 1.5
                anchors.bottom: editTextCircle.top
                anchors.bottomMargin: hmStyle.buttonMargin
                anchors.horizontalCenter: parent.horizontalCenter
            }

            HMTextCircle {
                id: editTextCircle
                height: hmStyle.circleHeight * 2
                width: height
                amountFontSize: hmStyle.mixIngredientAmountFontSize * 1.5
                value: editItem.flavorObject ? editItem.flavorObject.flavorAmount : 0
                text: value + "%"
                circleColor: editItem.flavorObject != null ? editItem.flavorObject.flavorColor : "white"
                anchors.centerIn: parent
            }

            HMButton {
                id: lessButton
                height: hmStyle.bottomButtonHeight*1.5
                width: hmStyle.bottomButtonHeight*1.5
                anchors {
                    verticalCenter: editTextCircle.verticalCenter
                    right: editTextCircle.left
                    rightMargin: hmStyle.buttonMargin*3
                }

                text: "—"
                onClicked: {
                    if(editItem.flavorObject && editItem.flavorObject.flavorAmount > 1)
                        editItem.flavorObject.flavorAmount--
                }
                onLongPressTick: {
                    if(editItem.flavorObject && editItem.flavorObject.flavorAmount > 1)
                        editItem.flavorObject.flavorAmount--
                }
            }

            HMButton {
                id: moreButton
                height: hmStyle.bottomButtonHeight*1.5
                width: hmStyle.bottomButtonHeight*1.5
                anchors {
                    verticalCenter: editTextCircle.verticalCenter
                    left: editTextCircle.right
                    leftMargin: hmStyle.buttonMargin*3
                }

                text: "+"
                onClicked: {
                    if(editItem.flavorObject && editItem.flavorObject.flavorAmount < 100)
                        editItem.flavorObject.flavorAmount++
                }
                onLongPressTick: {
                    if(editItem.flavorObject && editItem.flavorObject.flavorAmount < 100)
                        editItem.flavorObject.flavorAmount++
                }
            }


            HMRedButton {
                id: editRemoveButton
                anchors {
                    bottom: editSaveButton.top
                    bottomMargin: hmStyle.buttonMargin / 2
                    left: parent.left
                    right: parent.right
                    rightMargin: hmStyle.buttonMargin / 2
                    leftMargin: hmStyle.buttonMargin / 2
                }
                width: parent.width / 2
                height: hmStyle.bottomButtonHeight
                //: "REMOVE FROM MIX" button on ingredient editing screen
                text: qsTr("remove-ingredient-from-mix")
                onClicked: {
                    removeIngredientFromMix(editItem.flavorIndex)
                    closeItemEditing()
                }
            }

            HMButton {
                id: editSaveButton
                anchors {
                    bottom: parent.bottom
                    left: parent.left
                    right: parent.right
                    rightMargin: hmStyle.buttonMargin / 2
                    leftMargin: hmStyle.buttonMargin / 2
                }

                height: hmStyle.bottomButtonHeight
                //: "SAVE" button on ingredient editing screen
                text: qsTr("save-ingredient-from-mix")
                onClicked: closeItemEditing()
            }
        }
    }
}
