import QtQuick 2.2
import QtQuick.Controls 1.1
import HookahMixesModels 1.0
import QtQuick.Layouts 1.1


ScreenBase {
    id: screen

    screenName: "ScreenFoundInBooks" + (foundInBooksList.count > 0 ? "" : " empty");
    //: "Found in books" screen title
    screenTitle: qsTr("found-in-books-scren-title")

    function update() {
        updateLock();
    }

    signal updateLock();


//-----------------------------------------------------------------------------

    // Define a delegate component.  A delegate will be
    // instantiated for each visible item in the list.
    Component {
        id: delegate

        HMMenuItem {
            id: listItem
            property int savedBookId: bookIdField;
            property string bookAboutPage: utility.getBookAboutPage(savedBookId);

            anchors {
                left: parent.left
                right: parent.right
                leftMargin: hmStyle.menuItemLeftRightMargin
                rightMargin: hmStyle.menuItemLeftRightMargin
            }

            imageSource: utility.bookIconById(savedBookId)
            title: bookNameField
            //: text under each book: "recipes found: "
            description: qsTr("recipes-found-text") + mixesCountField
            separatorVisible: true

            locked: utility.isBookLocked(savedBookId)

            onClicked: {
                if(!listItem.locked) {
                    screensStack.openScreen(Qt.resolvedUrl("ScreenFoundMixesList.qml"), {"bookId": savedBookId, "aboutScreen": bookAboutPage, /*"screenTitle": bookNameField, */immediate: true });
                } else {
                    screensStack.openScreen(Qt.resolvedUrl("ScreenUnlock.qml"));
                }
            }

            function changeLock() {
                locked = utility.isBookLocked(savedBookId)
            }
            Component.onCompleted: {
                screen.updateLock.connect(changeLock);
            }
        }
    }

    DBModelFoundInBooks {
        id: dbModelFoundInBooks
    }

//-----------------------------------------------------------------------------

    // The actual list
    HMListView {
        id: foundInBooksList
        clip: true
        anchors.fill: parent
        model: dbModelFoundInBooks
        highlight: highlight
        delegate: delegate 	// Refers to the delegate component
    }

    HMText {
        id: noMixesFound
        anchors.centerIn: parent
        //: Text that displayed when no mixes found "No mixes was found"
        text: qsTr("no-mixes-found-text")
        visible: (foundInBooksList.count == 0)
        font.pixelSize: hmStyle.emptyListFontSize
    }

//-----------------------------------------------------------------------------


}
