import QtQuick 2.2
import QtQuick.Controls 1.1
import HookahMixesModels 1.0
import QtQuick.Layouts 1.1
import Enginio 1.0


ScreenBase {

    id: screen

//-----------------------------------------------------------------------------

    screenName: "ScreenMain";
    //: about screen title (Welcome)
    screenTitle: qsTr("main-screen-title")

    property bool allFitsTheScreen: ( titleRect.height + mainImage.height + menu.height + /*languageButton.height + 3*/2*hmStyle.mainScreenMargins ) < screen.height
    property bool allNewsChecked: true

    function update() {
        checkNews();
    }

    function checkNews() {
        edsClient.query({"objectType": "objects.news", "limit":1, "sort" : [{"sortBy":"createdAt","direction":"desc"}] }, Enginio.ObjectOperation)
    }

//-----------------------------------------------------------------------------

    EnginioClient {
        id: edsClient
        backendId: "55e94f6dc8e85c1d6003eb7c"
        onFinished: {
            if(reply.data.results != undefined) {
                var lastNewsTime = new Date(reply.data.results[0].createdAt)
                var lastCheckedTime = settings.lastNewsCheck()

                if( lastCheckedTime < lastNewsTime ) {
                    allNewsChecked = false
                } else {
                    allNewsChecked = true
                }
            }
        }
    }

    function actionTriggered(actionName, isToggled) {
        if(actionName === "showAbout") {
            screensStack.openScreen(Qt.resolvedUrl("ScreenAbout.qml"));
        }
    }    

    function menuItemClicked(menuItemId) {
        if(menuItemId === "MI_TUTORIALS") {
            screensStack.openScreen(Qt.resolvedUrl("ScreenTutorialsList.qml"));
        }
        else if(menuItemId === "MI_MYTOBACCO") {
            screensStack.openScreen(Qt.resolvedUrl("ScreenShelfContent.qml"));
        }
        else if(menuItemId === "MI_BOOKS") {
            screensStack.openScreen(Qt.resolvedUrl("ScreenBooks.qml"));
        }
        else if(menuItemId === "MI_NEWS") {
            screensStack.openScreen(Qt.resolvedUrl("ScreenNews.qml"));
        }
        else if(menuItemId === "MI_VK") {
            utility.openOfficialVk();
        }
    }

    Component.onCompleted: {
        var aboutButton = {'image':  "qrc:/images/about.png", 'action': "showAbout",'isToggleButton': false};
        navBarButtons.append(aboutButton)
    }

//-----------------------------------------------------------------------------

    Item {
        id: titleRect

        anchors.left: parent.left
        anchors.top: parent.top
        anchors.topMargin: hmStyle.mainScreenTopMargin
        anchors.right: parent.right
        height: titleItem.height

        Item {
            id: titleItem
            anchors.verticalCenter: parent.verticalCenter
            anchors.left: parent.left
            anchors.right: parent.right
            height: caption.height + titleDescription.height

            HMText{
                id: caption
                text: "HookahGusto"
                font.pixelSize: hmStyle.titleFontSize
                anchors.horizontalCenter: parent.horizontalCenter
                horizontalAlignment: Text.AlignHCenter
                verticalAlignment: Text.AlignVCenter
            }
            HMText{
                id: titleDescription
                anchors.top: caption.bottom
                anchors.left: parent.left
                anchors.right: parent.right
                //: App slogan - All you want to know about hookah
                text: qsTr("app-slogan")
                font.pixelSize: hmStyle.titleDespcriptionFontSize
                horizontalAlignment: Text.AlignHCenter
                verticalAlignment: Text.AlignVCenter
            }
        }
    }

    Flickable {

        anchors.left: parent.left
        anchors.right: parent.right
        anchors.top: titleRect.bottom
        anchors.bottom: parent.bottom
        clip:true
        contentHeight: allFitsTheScreen ? screen.height - titleRect.height - hmStyle.mainScreenTopMargin : mainImage.height + menu.height
                                          + /*languageButton.height + 3*/2*hmStyle.mainScreenMargins


        Image {
            id: mainImage

            anchors.left: parent.left
            anchors.right: parent.right
            anchors.top: parent.top
            anchors.topMargin: hmStyle.mainScreenMargins

            height : hmStyle.mainImageHeight
            fillMode: Image.PreserveAspectFit
            source: hmStyle.imageMain
        }

        ListView {
            id: menu
            anchors {
                left: parent.left
                right: parent.right
                top: mainImage.bottom
            }
            height: menu.count*hmStyle.listItemHeaderMenuHeight
            delegate: menuItemComponent
            //model: menuItemsModel

            Component {
                id: flavorsComponent
                DBModelFlavorsInTheBook {}
            }
            Component {
                id: linesComponent
                DBModelLinesInTheBook{}
            }

        }

        Component.onCompleted: {
            var tutorials = {'menuImageSource': hmStyle.imageTutorialsMenu,
                        'menuTitle': qsTr("tutorials-menu-text"),
                        'menuID': "MI_TUTORIALS"};

            var myTobacco = {'menuImageSource': hmStyle.imageMyTobaccoMenu,
                        'menuTitle': qsTr("my-tobacco-menu-text"),
                        'menuID': "MI_MYTOBACCO"};

            var books = {'menuImageSource': hmStyle.imageMixesMenu,
                'menuTitle': qsTr("mixes-text"),
                'menuID': "MI_BOOKS"};

//            var news = {'menuImageSource': hmStyle.imageNewsMenu,
//                'menuTitle': qsTr("news-text"),
//                'menuID': "MI_NEWS"};

            var vk = {'menuImageSource': hmStyle.imageVkMenu,
                'menuTitle': "МЫ ВКОНТАКТЕ",
                'menuID': "MI_VK"};



            menuItemsModel.append(tutorials);
            menuItemsModel.append(myTobacco);
            menuItemsModel.append(books);
            if(utility.russianTranslationLoaded) {
//                menuItemsModel.append(news);
                menuItemsModel.append(vk);
            }
            menu.model = menuItemsModel
        }

        ListModel {
            id: menuItemsModel
        }


        Component {
            id: menuItemComponent

            HMMainMenuItem{
                anchors {
                    left: parent.left
                    right: parent.right
                    leftMargin: hmStyle.mainMenuItemMargin
                    rightMargin: hmStyle.mainMenuItemMargin
                }
                separatorVisible: true
                imageSource: menuImageSource
                title: menuTitle

                onClicked: menuItemClicked(menuID)
                Component.onCompleted: {
                    if(menuID == "MI_NEWS") {
                        blinking = Qt.binding(function() { return !allNewsChecked })
                    }
                }
            }
        }
    }

//-----------------------------------------------------------------------------

}



