import QtQuick 2.2
import QtQuick.Layouts 1.1
import QtQuick.Controls 1.1
import HookahMixesModels 1.0


//-----------------------------------------------------------------------------

ScreenBase {

    id: screen

    screenName: "ScreenMixDetails";
    //: Title of "mix details" screen ("Mix details")
    screenTitle: qsTr("mix-details-screen-title")

//-----------------------------------------------------------------------------

    property int mixId
    property int bookId
    property bool isFavorite: databaseWriter.isFavorite(mixId)
    property bool allFitsTheScreen: ( mixControl.height + ratingControl.height + buttonsRow.height ) < screen.height
    property bool userWorkedWithMix: false

    signal updateMix()
//-----------------------------------------------------------------------------

    Component.onCompleted: {
        isFavorite = databaseWriter.isFavorite(mixId)

        if(bookId == utility.myMixesBookId()) {
            var editButton = {'image':"qrc:/images/xhdpi/edit.png",'action': "editMix",'isToggleButton': false};
            navBarButtons.append(editButton)
            var removeButton = {'image':"qrc:/images/xhdpi/Delete_nav.png",'action': "removeMix",'isToggleButton': false};
            navBarButtons.append(removeButton)
        }

    }
    function actionTriggered(actionName, isToggled) {
        if(actionName === "editMix") {
            screensStack.openScreen(Qt.resolvedUrl("ScreenEditMix.qml"), {"mixId": mixId});
        }
        if(actionName === "removeMix") {
            databaseWriter.removeUserMix(mixId)
            screensStack.closeScreen()
        }
    }

    function update() {
        updateMix()
    }

    Component.onDestruction: {
        if(userWorkedWithMix) {
            userWorksWithAppMaybeShowHimRateScreen();
        }
    }

    Flickable {
        anchors.top: parent.top
        anchors.bottom: buttonsRow.top
        anchors.left: parent.left
        anchors.right: parent.right

        contentWidth: parent.width
        contentHeight: dataControl.height
        clip: true

        ColumnLayout {
            id: dataControl

            anchors.left: parent.left
            anchors.right: parent.right
            anchors.top: parent.top
            height: allFitsTheScreen ? screen.height - buttonsRow.height : mixControl.height + ratingControl.height + hmStyle.mixTopBottomMargin*2


            Mix {
                id: mixControl

                mixId: screen.mixId
                createTextDescriptionForMix: true
                anchors.top: parent.top
                anchors.left: parent.left
                anchors.right: parent.right
                anchors.leftMargin: hmStyle.leftContentMargin
                anchors.rightMargin: hmStyle.rightContentMargin
                anchors.topMargin: hmStyle.mixTopBottomMargin
                anchors.bottomMargin: hmStyle.mixTopBottomMargin
                Component.onCompleted: screen.updateMix.connect(mixControl.update)
            }

            HMLayoutSpacer {}

            ColumnLayout {
                id: ratingControl
                anchors.left: parent.left
                anchors.right: parent.right
                anchors.bottomMargin: hmStyle.ratingControlBottomMargin
                height: ratingControlText.height + ratingControlRating.height

                HMText {
                    id: ratingControlText
                    //: Text that shown on "mix details" screen, saying "PLEASE RATE THE MIX"
                    text: qsTr("please-rate-mix-text")
                    anchors.horizontalCenter: parent.horizontalCenter
                    font.pixelSize: hmStyle.rateMixFontSize
                }

                HMRating {
                    id: ratingControlRating
                    anchors.horizontalCenter: parent.horizontalCenter
                    height: hmStyle.starIconHeightWidth
                    width: hmStyle.starIconHeightWidth*5

                    interactive: true
                    mixIdValue: screen.mixId

                    onNewRatingSet: {
                        userWorkedWithMix=true
                    }
                }
            }

            HMLayoutSpacer {}
        }
    }


    RowLayout {
        id: buttonsRow

        height: hmStyle.bottomButtonHeight
        anchors {
            bottom: parent.bottom
            left: parent.left
            right: parent.right
            leftMargin: hmStyle.buttonMargin
            rightMargin: hmStyle.buttonMargin
        }

        HMButtonSmall {
            Layout.fillWidth: true
            Layout.fillHeight: true

            //qsTr("Remove from") : qsTr("Add to")
            textLine1: isFavorite ? qsTr("favorite-button-line1") : qsTr("not-favorite-button-line1")
            //textLine2: qsTr("favorites")
            textLine2: isFavorite ? qsTr("favorite-button-line2") : qsTr("not-favorite-button-line2")
            iconSource: isFavorite ? hmStyle.removeFavoriteButtonIcon : hmStyle.addFavoriteButtonIcon
            dividerSource: hmStyle.imageFavButtonDivider

            onClicked: {
                if( isFavorite ){
                    databaseWriter.removeFavorite(mixId)
                    utility.googleAnalyticsHitAction("functionality", "removeMixFromFavorite")
                }
                else {
                    databaseWriter.addFavorite(mixId)
                    utility.googleAnalyticsHitAction("functionality", "addMixToFavorite")
                }
                isFavorite = databaseWriter.isFavorite(mixId)
                userWorkedWithMix=true
            }
        }

        HMVioletButton {
            Layout.fillHeight: true
            Layout.fillWidth: true

            id: shareButton
            //: Share button first line text ("share")
            textLine1: qsTr("share-button-line1")
            //: Share button second line text ("with friends")
            textLine2: qsTr("share-button-line2")
            iconSource: hmStyle.shareButtonIcon
            dividerSource: hmStyle.imageSocButtonDivider
            onClicked: {
                utility.googleAnalyticsHitAction("functionality", "shareMixWithFriends")
                utility.makeScreenshot();
                screensStack.openScreen(Qt.resolvedUrl("ScreenShare.qml"), {"shareType": ISharer.TellAboutMix, "mixDescription": mixControl.mixDescription, "mixId": screen.mixId });
            }
        }
    }
}
