import QtQuick 2.2
import HookahMixesModels 1.0


ScreenBase {

    id: screen
    property var dbModel;
    property bool noMixesFoundTextVisible: false;
    property bool mixesListIsEmpty: mixesList.count == 0
//-----------------------------------------------------------------------------

    property int bookId
    property string aboutScreen: ""
    onAboutScreenChanged: recreateNavBarButtons()

    screenName: "ScreenMixesListBase";
    signal updateMixRatings()

    function update() {
        updateMixRatings()

        var rememberedY = mixesList.contentY
        dbModel.updateData()
        mixesList.contentY = rememberedY
    }

    function processBackPress(){
        if(dbModel.isFilterApplied())
        {
            filterControl.resetSelection();
            return true;
        }

        return false;
    }

    Component.onCompleted: {
        recreateNavBarButtons()
    }
    function recreateNavBarButtons() {
        navBarButtons.clear()
        var filterButton = {'image':"qrc:/images/xhdpi/Search_ic.png",'action': "filter",'isToggleButton': false};
        navBarButtons.append(filterButton)
        if(aboutScreen != "") {
            var showAboutButton = {'image':"qrc:/images/about.png",'action': "showAbout",'isToggleButton': false};
            navBarButtons.append(showAboutButton)
        }
    }

//-----------------------------------------------------------------------------

    // Define a delegate component.  A delegate will be
    // instantiated for each visible item in the list.
    Component {
        id: delegateComponent

        Item {
            id: rootRectangle
            anchors.left: parent.left
            anchors.right: parent.right
            height: mixControl.height + ratingControl.height + separator.height + ( ratingControl.visible ? 3:2 )*hmStyle.mixesListMixTopBottomMargin

            Mix {
                id: mixControl
                anchors.top: parent.top
                anchors.left: parent.left
                anchors.right: parent.right

                anchors.rightMargin: hmStyle.rightContentMargin
                anchors.topMargin: hmStyle.mixesListMixTopBottomMargin
                anchors.bottomMargin: ratingControl.visible ? 0 : hmStyle.mixesListMixTopBottomMargin

                mixId: mixIdField
            }

            Rectangle {
                id: separator
                anchors.top: mixControl.bottom
                anchors.left: parent.left
                anchors.right: parent.right

                height: visible ? 1 : 0


                color: index%2 ? "white" : "black"
                opacity: hmStyle.separatorOpacity
                visible: ratingControl.visible
            }

            HMRating {
                id: ratingControl
                anchors.top: separator.bottom
                anchors.horizontalCenter: parent.horizontalCenter

                mixIdValue: mixIdField

                height: hmStyle.mixesListRatingHeight*visible
                width: hmStyle.mixesListRatingHeight*5
                visible: mixRating > 0
                anchors.bottomMargin: visible ? hmStyle.mixesListMixTopBottomMargin : 0
                anchors.topMargin: visible ? hmStyle.mixesListMixTopBottomMargin : 0
            }

            MouseArea {
                anchors.fill: parent
                onClicked: {
                    screensStack.openScreen(Qt.resolvedUrl("ScreenMixDetails.qml"), {"mixId": mixControl.mixId, "bookId": bookId, immediate: true });
                }
            }
            HMTransparentBackground {
                anchors.fill:parent
                z: -1
                color: "white"
                opacity: index%2 ? 0 : 0.2
            }

        }
    }

    HMListView {
        id: mixesList
        clip: true
        anchors.fill: parent
        model: 3
        spacing: 2
        snapMode: ListView.SnapOneItem

        delegate: Component {

            HMListView {
                height: mixesList.height//parent.height
                width: mixesList.width//parent.width
                model: dbModel
                delegate: delegateComponent 	// Refers to the delegate component
                Component.onCompleted: console.log("dbModel=", dbModel, "height: ", height, "width:", width)
            }
        }

        orientation: ListView.Horizontal
        Component.onCompleted: console.log("!!! height: ", height, "width:", width)
    }


//    // The actual list
//    HMListView {
//        id: mixesList
//        clip: true
//        anchors.fill: parent
//        model: dbModel
//        delegate: delegateComponent 	// Refers to the delegate component
//    }

    HMText {
        id: noMixesFound
        anchors.centerIn: parent
        //: Text that displayed when no mixes for filter "No mixes was found"
        text: qsTr("no-mixes-for-filter-text")
        visible: screen.noMixesFoundTextVisible;
        font.pixelSize: hmStyle.emptyListFontSize
    }
}
