import QtQuick 2.5
import HookahMixesModels 1.0
import Enginio 1.0

ScreenBase {

    id: screen

    screenName: "ScreenNews";
    // "News" screen title
    screenTitle: qsTr("news-screen-title")

    function update(){

    }

    property var imagesUrl: new Object
    property bool networkError: false
    property bool loading: true

//-----------------------------------------------------------------------------

    HMListView {
        id: listview
        model: edsNewsModel
        delegate: listItemDelegate
        anchors.fill: parent
    }

    EnginioClient {
        id: edsClient
        backendId: "55e94f6dc8e85c1d6003eb7c"
        onError: {
            networkError = true
        }
        onFinished: {
            loading = false
            //log news check so we don't show it as "new" anymore
            if(!networkError) {
                settings.logNewsCheck()
            }
        }
    }

    EnginioModel {
        id: edsNewsModel
        client: edsClient
        query: {"objectType": "objects.news", "limit":10, "sort" : [{"sortBy":"createdAt","direction":"desc"}] }
    }

    Component {
        id: listItemDelegate

        HMMenuItem {
            id: listItem

            anchors {
                left: parent.left
                right: parent.right
                leftMargin: hmStyle.menuItemLeftRightMargin
                rightMargin: hmStyle.menuItemLeftRightMargin
            }

            title: model.title
            description: model.description
            separatorVisible: true
            showLoading: true

            onClicked: {
                var analyticsName = "news-"+model.analyticsTitle
                utility.googleAnalyticsHitScreen(analyticsName)
                utility.openUrl(model.url);
            }

            Component.onCompleted: {
                if (id in imagesUrl)
                {
                    imageSource = imagesUrl[id]
                }
                else
                {
                    console.log("---------------")
                    console.log("model.title:", model.title)
                    console.log("model.image:", model.image)
                    console.log("model.image.id:", model.image.id)
                    if(model.image) {
                        var data = { "id": model.image.id }
                        var reply = edsClient.downloadUrl(data)
                        reply.finished.connect(function() {
                            imagesUrl[id] = reply.data.expiringUrl
                            if (listItem && reply.data.expiringUrl) { // It may be deleted as it is delegate
                                imageSource = reply.data.expiringUrl
                            }
                        })
                    }
                }
            }

        }
    }

    HMText {
        id: noNewsFound1
        anchors.bottom: centerItem.top
        anchors.horizontalCenter: parent.horizontalCenter
        //: Text that displayed when no news displayed
        text: qsTr("no-news-found")
        visible: networkError
        font.pixelSize: hmStyle.emptyListFontSize
    }

    Item {
        id: centerItem
        anchors.centerIn: parent
        visible: networkError
    }

     AnimatedImage {
        height: hmStyle.loadingIconHeight
        width: hmStyle.loadingIconHeight
        id: loadingImage
        anchors.centerIn: parent
        visible: screen.loading
        source: "qrc:/images/loading.gif"
        asynchronous: true
    }

    HMText {
        id: noNewsFound2
        anchors.top: centerItem.bottom
        anchors.horizontalCenter: parent.horizontalCenter
        //: Check internet connection
        text: qsTr("check-internet-connection")
        visible: networkError
        font.pixelSize: hmStyle.emptyListFontSize
    }



//-----------------------------------------------------------------------------
}
