import QtQuick 2.2
import QtQuick.Controls 1.1
import HookahMixesModels 1.0
import QtQuick.Layouts 1.1


ScreenBase {
    id: screen

//-----------------------------------------------------------------------------

    screenName: "ScreenShelfContent";
    property bool shelfIsEmpty: linesListView.count == 0

    //: "BACK TO SHELF" button text
    property string backButtonText : qsTr("back-to-shelf-button-text")
    //: Text on the button that adds flavors to the shelf "Add to the shelf"
    property string addFlavorsButtonText: qsTr("add-to-shelf-button-text")


    Item {
        id: addFlavorsFunctor
        function addFlavors(flavorsList) {
            databaseWriter.addFlavorsToTheShelf(flavorsList)
        }
    }
    function openSelectFlavorsWindow() {
        screensStack.openScreen(Qt.resolvedUrl("ScreenSelectBrand.qml"), {"functorToCallOnAdd":addFlavorsFunctor, "backButtonText":backButtonText, "addFlavorsButtonText":addFlavorsButtonText});
    }

    states: [
            State {
                name: "Initial"
            },
            State {
                name: "RemoveFlavors"
            }
        ]

    onStateChanged: {
        controller.clearSelectedChilds();
    }

    Component.onCompleted: {
        recreateNavBarButtons()
    }
    function recreateNavBarButtons() {
        navBarButtons.clear()
        var addButton = {'image':"qrc:/images/xhdpi/Add_nav.png",'action': "addFlavors",'isToggleButton': false};
        navBarButtons.append(addButton)
        if(!shelfIsEmpty) {
            var removeButton = {'image':"qrc:/images/xhdpi/Delete_nav.png",'action': "removeFlavors",'isToggleButton': true};
            navBarButtons.append(removeButton)
        }
    }

//-----------------------------------------------------------------------------

    QtObject{
        id: internal
        property string flavorItemImage: ""
    }

    //: "Flavors you have" screen title
    screenTitle: qsTr("your-flavors-screen-title")
    state: "Initial"
    onShelfIsEmptyChanged: recreateNavBarButtons()

    function update() {       
        dbModelLinesOnTheShelf.updateData()
    }

    function actionTriggered(actionName, isToggled) {
        if(actionName === "addFlavors") {
            openSelectFlavorsWindow()
        }
        if(actionName === "removeFlavors") {
            if(state === "Initial")
                state = "RemoveFlavors"
            else
                state = "Initial"
        }
    }

    function isNavBarButtonToggled(action) {
        if(action === "removeFlavors") {
            return screen.state === "RemoveFlavors"
        }
        else
            return false;
    }

    function removeFlavors() {
        var rememberedY = linesListView.contentY
        databaseWriter.removeFlavorsFromTheShelf( controller.selectedChildren() );
        screen.update()
        linesListView.contentY = rememberedY
    }

    ListModel {
        id: navigationBarButtons

        ListElement {
            image:  "qrc:/images/xhdpi/Add_nav.png"
            action: "addFlavors"
            isToggleButton: false
        }
        ListElement {
            image: "qrc:/images/xhdpi/Delete_nav.png" //hmStyle.imageNavBarDelete
            action: "removeFlavors"
            isToggleButton: true
        }
    }

    ListModel {
        id: navigationBarButtonsWhenEmpty

        ListElement {
            image: "qrc:/images/xhdpi/Add_nav.png" //hmStyle.imageNavBarAdd
            action: "addFlavors"
            isToggleButton: false
        }
    }

//-----------------------------------------------------------------------------

    //controller
    ControllerShelfContent {
        id: controller
    }

    DBModelLinesOnTheShelf {
        id: dbModelLinesOnTheShelf
    }

//-----------------------------------------------------------------------------

    Component {
        id: delegate

        Column {

            anchors.left: parent.left
            anchors.right: parent.right
            spacing: 1

            ListItemHeader {
                id: groupElement
                anchors.left: parent.left
                anchors.right: parent.right

                title: makerNameField
                description: lineNameField
                separatorVisible: true
                state: controller.isGroupExpanded(lineIdField) ? "expanded" : "collapsed"

                onClicked: {
                    childsElement.visible = !childsElement.visible
                    if(childsElement.visible)
                        controller.expandGroup(lineIdField)
                    else
                        controller.collapseGroup(lineIdField)
                }
                Component.onCompleted: {
                    if (index == 0 ) {
                        controller.expandGroup(lineIdField)
                    }
                }
            }

            DBModelCansOnTheShelf {
                id: dbModelCansOnTheShelf
                lineId: lineIdField
            }

            ListView{
                id: childsElement
                spacing: 1


                anchors.left: parent.left
                anchors.right: parent.right
                height: childsElement.count * hmStyle.listItemFlavorHeight + (childsElement.count-1)

                visible: controller.isGroupExpanded(lineIdField)
                interactive: false

                model:dbModelCansOnTheShelf

                delegate: ListItemFlavor {
                    id: childsLayout

                    visible: childsElement.visible
                    anchors.left: parent.left
                    anchors.right: parent.right

                    flavorId: flavorIdField
                    colorBlockColor: flavorColorField
                    text: flavorNameField

                    selected: controller.isChildSelected(flavorId)
                    onClicked: {
                        if(screen.state === "RemoveFlavors") {
                            if(controller.isChildSelected(flavorId)){
                                controller.deselectChild(flavorId)
                            }
                            else
                                controller.selectChild(flavorId)

                            selected = controller.isChildSelected(flavorId)
                        }
                    }

                    function updateSelection() {
                        if( controller ) {
                            selected = controller.isChildSelected(flavorId)
                        }
                    }

                    Component.onCompleted: {
                        screen.stateChanged.connect(updateSelection);
                    }

                }
            }
        }
    }

//-----------------------------------------------------------------------------


    ColumnLayout {
        anchors.fill: parent


        // list of flavors on the shelf
        ListView {
            id: linesListView
            Layout.fillWidth: true
            Layout.fillHeight: true
            model: dbModelLinesOnTheShelf
            delegate: delegate 	// Refers to the delegate component
            clip: true
        }

        Item {
            height: hmStyle.bottomButtonHeight + hmStyle.buttonMargin
            Layout.fillWidth: true

            HMButton {
                id: findMixesButton
                visible: !shelfIsEmpty && screen.state === "Initial"

                height: hmStyle.bottomButtonHeight
                anchors {
                    left: parent.left
                    right: parent.right
                    bottom: parent.bottom
                    leftMargin: hmStyle.buttonMargin
                    rightMargin: hmStyle.buttonMargin
                    bottomMargin: hmStyle.buttonMargin
                }

                iconSource: hmStyle.searchButtonIcon
                //: "FIND MIXES" button text
                text: qsTr("find-mixes-button-text")
                state: linesListView.count > 0 ? "enabled" : "disabled"
                onClicked: {
                    utility.googleAnalyticsHitAction("functionality", "findMixes")
                    screensStack.openScreen(Qt.resolvedUrl("ScreenFoundInBooks.qml"));
                }
            }

            HMRedButton {
                id: removeFlavorsButton
                visible: !shelfIsEmpty && screen.state === "RemoveFlavors"

                height: hmStyle.bottomButtonHeight
                anchors {
                    left: parent.left
                    right: parent.right
                    bottom: parent.bottom
                    leftMargin: hmStyle.buttonMargin
                    rightMargin: hmStyle.buttonMargin
                    bottomMargin: hmStyle.buttonMargin
                }

                iconSource: hmStyle.deleteButtonIcon
                //: "REMOVE FLAVORS" button text
                text: qsTr("remove-flavors-button-text")
                state: linesListView.count > 0 ? "enabled" : "disabled"
                imageSource: hmStyle.imageRemoveFlavorsButton
                onClicked: {
                    removeFlavors();
                }
            }
        }
    }


    HMButtonAdd {
        id: visibleWhenEmpty
        visible: shelfIsEmpty
        showSecondTextLine: true
        //: "ADD SOME FLAVORS" text
        firstLineText: qsTr("add-flavors-text")
        //: "TO YOUR SHELF" text
        secondLineText: qsTr("to-your-shelf-text")
        onClicked: {
            openSelectFlavorsWindow()
        }
    }
}
