import QtQuick 2.2
import HookahMixesModels 1.0

ScreenBase {

    //-----------------------------------------------------------------------------

    screenName: "ScreenTutorial " + tutorialName;
    property alias tutorialFile: tutorialModel.fileName
    property string tutorialName

    function update(){
    }

    function processBackPress(){
        if(overlayImage.visible == true)
        {
            hideImage();
            return true; //backPress processed
        }

        return false;
    }

    Component.onDestruction: {
        userWorksWithAppMaybeShowHimRateScreen();
    }

    function showImage(imagePath, imageDescription, imageSource) {
        overlayImage.visible = true;
        imageCloseup.visible = true;
        imageDescriptionControl.visible = true;
        imageSourceControl.visible = true;
        imageCloseup.source = imagePath;
        imageDescriptionControl.text = imageDescription;
        imageSourceControl.text = imageSource;
    }

    function hideImage() {
        overlayImage.visible = false;
        imageCloseup.visible = false;
        imageDescriptionControl.visible = false;
        imageSourceControl.visible = false;
    }

    //-----------------------------------------------------------------------------

    TutorialModel {
        id: tutorialModel
    }


    Component {
        id: sectionComponent

        Item {
            anchors {
                left: parent.left
                right: parent.right
            }
            height: text.height + image.height

            HMText {
                id: text
                property var obj;

                font.pixelSize: {
                    if(section.isHeader)
                        return hmStyle.tutorialsHeaderSize
                    else if (section.isSubHeader)
                        return hmStyle.tutorialsSubHeaderSize
                    else
                        return hmStyle.tutorialsFontSize
                }

                horizontalAlignment: section.isHeader ? Text.AlignHCenter : Text.AlignJustify

                anchors {
                    left: parent.left
                    right: parent.right
                }
                text: section.sectionText
                wrapMode: Text.Wrap
                visible: !section.isImage

            }

            Image {
            id:image
            asynchronous: true
            anchors {
                left: parent.left
                right: parent.right
                leftMargin: hmStyle.tutorialsLeftRightMargin*3
                rightMargin: hmStyle.tutorialsLeftRightMargin*3
            }

            source: section.isImage ? utility.tutorialsImagePath(section.sectionText) : "";
            visible: section.isImage
            height: section.isImage ? hmStyle.tutorialsImageHeight : 0
            fillMode: Image.PreserveAspectCrop
            MouseArea {
                anchors.fill: parent
                onClicked: {
                    showImage(image.source, section.imageDescription, section.imageSource)
                }
            }
            }
        }
    }



    HMListView {
        spacing: hmStyle.tutorialsSpacing
        anchors {
            fill: parent
            leftMargin: hmStyle.tutorialsLeftRightMargin
            rightMargin: hmStyle.tutorialsLeftRightMargin
        }
        model: tutorialModel
        delegate: sectionComponent
    }

    Rectangle {
        id: overlayImage
        color: "black"
        opacity: 0.8
        anchors.fill: parent
        visible: false

        MouseArea {
            anchors.fill: parent
            onClicked: hideImage()
        }
    }

    Image {
        id: imageCloseup
        visible: false
        fillMode: Image.PreserveAspectFit
        anchors {
            fill: parent
            leftMargin: hmStyle.tutorialsLeftRightMargin
            rightMargin: hmStyle.tutorialsLeftRightMargin
            topMargin: hmStyle.tutorialsLeftRightMargin
            bottomMargin: hmStyle.tutorialsBottomMargin
        }
    }

    HMText {
        id: imageDescriptionControl
        font.pixelSize: hmStyle.tutorialsImageDescriptionFontSize
        anchors {
            left: parent.left
            right: parent.right
            bottom: imageSourceControl.top
        }
        horizontalAlignment: Text.AlignHCenter
    }

    HMText {
        id: imageSourceControl
        font.pixelSize: hmStyle.tutorialsImageSourceFontSize
        anchors {
            left: parent.left
            right: parent.right
            bottom: parent.bottom
        }
        horizontalAlignment: Text.AlignHCenter

    }


    //-----------------------------------------------------------------------------
}
