import QtQuick 2.2
import HookahMixesModels 1.0

ScreenBase {

    id: screen

    screenName: "ScreenTutorialsList";
    //: "Tutorials" screen title
    screenTitle: qsTr("tutorials-screen-title")

    function update(){
        updateLock();
    }
    signal updateLock();

    //-----------------------------------------------------------------------------


    ListModel {
        id: tutorialsModel

        ListElement {
            tutorialIcon: "qrc:/images/01_construction.png"
            tutorialFileResource: "://tutorials/01_hookah_construction.txt"
            //: "Hookah construction" tutorial title
            tutorialTitle: QT_TR_NOOP("tut-hookah-construction")
            //: "Great tutorial" description
            tutorialDescription: QT_TR_NOOP("tut-hookah-construction-descr")
        }

        ListElement {
            tutorialIcon: "qrc:/images/02_choosing.png"
            tutorialFileResource: "://tutorials/02_choosing_hookah.txt"
            //: "choosing hookah" tutorial title
            tutorialTitle: QT_TR_NOOP("tut-choosing-hookah")
            //: "choosing hookah" description
            tutorialDescription: QT_TR_NOOP("tut-choosing-hookah-descr")
        }

        ListElement {
            tutorialIcon: "qrc:/images/03_tobacco.png"
            tutorialFileResource: "://tutorials/03_hookah_tobacco.txt"
            //: "hookah tobacco" tutorial title
            tutorialTitle: QT_TR_NOOP("tut-hookah-tobacco")
            //: "hookah tobacco" description
            tutorialDescription: QT_TR_NOOP("tut-hookah-tobacco-descr")
        }

        ListElement {
            tutorialIcon: "qrc:/images/04_bowls.png"
            tutorialFileResource: "://tutorials/04_bowl_shapes.txt"
            //: "hookah tobacco" tutorial title
            tutorialTitle: QT_TR_NOOP("tut-bowl-shapes")
            //: "hookah tobacco" description
            tutorialDescription: QT_TR_NOOP("tut-bowl-shapes-descr")
        }

        ListElement {
            tutorialIcon: "qrc:/images/05_charcoal.png"
            tutorialFileResource: "://tutorials/05_charcoal_types.txt"
            //: "hookah tobacco" tutorial title
            tutorialTitle: QT_TR_NOOP("tut-charcoal-types")
            //: "hookah tobacco" description
            tutorialDescription: QT_TR_NOOP("tut-charcoal-types-descr")
        }

        ListElement {
            tutorialIcon: "qrc:/images/06_classic.png"
            tutorialFileResource: "://tutorials/06_classic_pack.txt"
            //: "Classic pack" tutorial title
            tutorialTitle: QT_TR_NOOP("tut-classic-pack")
            //: "Classic pack" description
            tutorialDescription: QT_TR_NOOP("tut-charcoal-classic-pack")
        }

        ListElement {
            tutorialIcon: "qrc:/images/07_ring.png"
            tutorialFileResource: "://tutorials/07_ring_pack.txt"
            //: "ring pack" tutorial title
            tutorialTitle: QT_TR_NOOP("tut-ring-pack")
            //: "ring pack" description
            tutorialDescription: QT_TR_NOOP("tut-charcoal-ring-pack")
        }

        ListElement {
            tutorialIcon: "qrc:/images/08_overpack.png"
            tutorialFileResource: "://tutorials/08_overpack.txt"
            //: "overpack" tutorial title
            tutorialTitle: QT_TR_NOOP("tut-08-overpack")
            //: "overpack" description
            tutorialDescription: QT_TR_NOOP("tut-08-overpack-descr")
        }

        ListElement {
            tutorialIcon: "qrc:/images/09_windcover.png"
            tutorialFileResource: "://tutorials/09_windcover.txt"
            //: "windcover" tutorial title
            tutorialTitle: QT_TR_NOOP("tut-09-windcover")
            //: "windcover" description
            tutorialDescription: QT_TR_NOOP("tut-09-windcover-descr")
        }

        ListElement {
            tutorialIcon: "qrc:/images/10_heatcontrol.png"
            tutorialFileResource: "://tutorials/10_heat_management.txt"
            //: "heat management" tutorial title
            tutorialTitle: QT_TR_NOOP("tut-10-heat-management")
            //: "heat management" description
            tutorialDescription: QT_TR_NOOP("tut-10-heat-management-descr")
        }

        ListElement {
            tutorialIcon: "qrc:/images/11_apple.png"
            tutorialFileResource: "://tutorials/11_apple_bowl.txt"
            //: "apple bowl" tutorial title
            tutorialTitle: QT_TR_NOOP("tut-11-apple-bowl")
            //: "apple bowl" description
            tutorialDescription: QT_TR_NOOP("tut-11-apple-bowl-descr")
        }

        ListElement {
            tutorialIcon: "qrc:/images/12_orange.png"
            tutorialFileResource: "://tutorials/12_orange_bowl.txt"
            //: "orange bowl" tutorial title
            tutorialTitle: QT_TR_NOOP("tut-12-orange-bowl")
            //: "orange bowl" description
            tutorialDescription: QT_TR_NOOP("tut-12-orange-bowl-descr")
        }

        ListElement {
            tutorialIcon: "qrc:/images/13_cleaning.png"
            tutorialFileResource: "://tutorials/13_washing_hookah.txt"
            //: "washing hookah" tutorial title
            tutorialTitle: QT_TR_NOOP("tut-13-washing-hookah")
            //: "washing hookah" description
            tutorialDescription: QT_TR_NOOP("tut-13-washing-hookah-descr")
        }
    }


    // Define a delegate component.  A delegate will be
    // instantiated for each visible item in the list.
    Component {
        id: delegate

        HMMenuItem {
            id: listItem

            anchors {
                left: parent.left
                right: parent.right
                leftMargin: hmStyle.menuItemLeftRightMargin
                rightMargin: hmStyle.menuItemLeftRightMargin
            }

            locked: utility.isTutorialLocked(index)

            imageSource: tutorialIcon
            title: qsTranslate("ScreenTutorialsList", tutorialTitle)
            description: qsTranslate("ScreenTutorialsList", tutorialDescription)
            separatorVisible: true

            onClicked: {
                if(!listItem.locked) {
                    screensStack.openScreen(Qt.resolvedUrl("ScreenTutorial.qml"), {tutorialFile: utility.tutorialPath(tutorialFileResource),
                                                                                   screenTitle: qsTr("tutorials-screen-title"),
                                                                                   tutorialName: tutorialTitle} );
                } else {
                    screensStack.openScreen(Qt.resolvedUrl("ScreenUnlock.qml"));
                }
            }

            function changeLock() {
                locked = utility.isTutorialLocked(index)
            }
            Component.onCompleted: {
                screen.updateLock.connect(changeLock);
            }
        }
    }

    DBModelBooksList {
        id: dbModelBooksList
    }

//-----------------------------------------------------------------------------

    // The actual list
    HMListView {
        clip: true
        id: listControl
        anchors.fill: parent
        model: tutorialsModel
        delegate: delegate 	// Refers to the delegate component
    }

//-----------------------------------------------------------------------------
}
