import QtQuick 2.2
import HookahMixesModels 1.0
import QtPurchasing 1.0


ScreenBase {

    id: screen

    screenName: "ScreenUnlock";
    //: "Unlock" screen title
    screenTitle: qsTr("unlock-screen-title")

    function update(){
    }

    //-----------------------------------------------------------------------------

    Store {
        id: store
        Product {
            id: hookahGustoUnlockProduct
            identifier: {

                if(Qt.platform.os == "ios") {
                    return "HookahGustoUnlock";
                }
                else if(Qt.platform.os == "android") {
                    return "hookahgustounlock"
                }
            }

            type: Product.Unlockable

            onPurchaseRestored: {
                successfulUnlock(transaction);
            }

            onPurchaseSucceeded: {
                successfulUnlock(transaction);
            }

            onPurchaseFailed: {
                console.log("purchase failed: ")
                transaction.finalize()
            }

            Component.onCompleted: {
                printProductStatus()
            }
            onStatusChanged: printProductStatus()

            function successfulUnlock(transaction) {
                settings.setProUnlocked(true);
                transaction.finalize()
                screensStack.closeScreen()
                screensStack.openScreen(Qt.resolvedUrl("ScreenShareSuccess.qml"));
            }

            function printProductStatus() {
                if(status == Product.Uninitialized) {
                    console.log("status = Product.Uninitialized")
                } else if(status == Product.PendingRegistration ) {
                    console.log("status = Product.PendingRegistration")
                } else if(status == Product.Registered  ) {
                    console.log("status = Product.Registered ")
                } else if(status == Product.Unknown   ) {
                    console.log("status = Product.Unknown")
                }
            }
        }
    }

    Item {

        anchors {
            left: parent.left
            right: parent.right
            centerIn: parent
            verticalCenter: parent.verticalCenter
        }

        width: 0.75*parent.width
        height: headerText1.height + headerText2.height + shareButton.height + 5*priv.spacing

        QtObject {
            id: priv
            property int spacing: hmStyle.dp(5)
        }

        HMText {
            id: headerText1
            anchors.top: parent.top
            anchors.horizontalCenter: parent.horizontalCenter
            //: "Unlock HookahGusto" text
            text: qsTr("unlock-hookahgusto")
            wrapMode: Text.WordWrap
            font.pixelSize: hmStyle.unlockHeaderFontSize

        }
        HMText {
            id: headerText2
            anchors {
                top: headerText1.bottom
                horizontalCenter: parent.horizontalCenter
            }

            //: "and get access to all sections!"
            text: qsTr("get-access-text")
            wrapMode: Text.WordWrap
            font.pixelSize: hmStyle.unlockHeaderFontSize
        }

        HMButton {
            id: shareButton
            anchors {
                top: headerText2.bottom
                topMargin: priv.spacing*5
                left: parent.left
                right: parent.right
            }

            //: "Purchase" button text
            property string buyText: qsTr("share-unlock-button-text")

            //: "Purchase for...!" button text
            property string buyForText: qsTr("share-unlock-for-button-text") + " " + hookahGustoUnlockProduct.price


            text: hookahGustoUnlockProduct.status != Product.Registered ? buyText : buyForText

            height: hmStyle.bottomButtonHeight
            capitalization: Font.MixedCase

            onClicked: {
                hookahGustoUnlockProduct.purchase()
//                screensStack.closeScreen()
//                screensStack.openScreen(Qt.resolvedUrl("ScreenShare.qml"), {"shareType": ISharer.TellAboutHookahGusto });
            }
        }

        HMButton {
            id: restoreButton
            anchors {
                top: shareButton.bottom
                topMargin: priv.spacing*5
                left: parent.left
                right: parent.right
            }
            //: "Restore" button text
            text: qsTr("share-reslotre-button-text")
            height: hmStyle.bottomButtonHeight
            capitalization: Font.MixedCase

            onClicked: {
                store.restorePurchases()
//                screensStack.closeScreen()
//                screensStack.openScreen(Qt.resolvedUrl("ScreenShare.qml"), {"shareType": ISharer.TellAboutHookahGusto });
            }
        }
    }

    HMButton {
        id: noThanksButton
        anchors {
            bottom: parent.bottom
            left: parent.left
            right: parent.right
            leftMargin: hmStyle.buttonMargin
            rightMargin: hmStyle.buttonMargin
            bottomMargin: hmStyle.buttonMargin
        }
        //: "No, Thanks" button text
        text: qsTr("no-button-text")
        height: hmStyle.bottomButtonHeight
        capitalization: Font.MixedCase

        onClicked: {
            screensStack.closeScreen()
        }
    }


    //-----------------------------------------------------------------------------
}

//import QtQuick 2.2
//import QtQuick.Layouts 1.1
//import HookahMixesModels 1.0
//import QtPurchasing 1.0


//ScreenBase {

//    id: screen

//    screenName: "ScreenUnlock";
//    //: "Unlock" screen title
//    screenTitle: qsTr("unlock-screen-title")
//    property var unlockProduct: utility.discountValid ? hookahGustoUnlockProduct : hookahGustoUnlockProduct_FullPrice


//    function update(){
//    }

//    //-----------------------------------------------------------------------------

//    Store {
//        id: store

//        function successfulUnlock(transaction) {
//            settings.setProUnlocked(true);
//            transaction.finalize()
//            screensStack.closeScreen()
//            screensStack.openScreen(Qt.resolvedUrl("ScreenShareSuccess.qml"));
//        }

//        function printProductStatus(status) {
//            if(status == Product.Uninitialized) {
//                console.log("status = Product.Uninitialized")
//            } else if(status == Product.PendingRegistration ) {
//                console.log("status = Product.PendingRegistration")
//            } else if(status == Product.Registered  ) {
//                console.log("status = Product.Registered ")
//            } else if(status == Product.Unknown   ) {
//                console.log("status = Product.Unknown")
//            }
//        }

//        Product {
//            id: hookahGustoUnlockProduct
//            identifier: {

//                if(Qt.platform.os == "ios") {
//                    return "HookahGustoUnlock";
//                }
//                else if(Qt.platform.os == "android") {
//                    return "hookahgustounlock"
//                }
//                else {
//                    return ""
//                }
//            }
//            type: Product.Unlockable
//            onPurchaseRestored: store.successfulUnlock(transaction);
//            onPurchaseSucceeded: store.successfulUnlock(transaction);
//            onPurchaseFailed: transaction.finalize()
//            Component.onCompleted: store.printProductStatus(status)
//            onStatusChanged: store.printProductStatus(status)
//        }

//        Product {
//            id: hookahGustoUnlockProduct_FullPrice
//            identifier: {

//                if(Qt.platform.os == "ios") {
//                    return "HookahGustoUnlock";
//                }
//                else if(Qt.platform.os == "android") {
//                    return "hookahgustounlock_fullprice"
//                }
//                else {
//                    return ""
//                }
//            }
//            type: Product.Unlockable
//            onPurchaseRestored: store.successfulUnlock(transaction);
//            onPurchaseSucceeded: store.successfulUnlock(transaction);
//            onPurchaseFailed: transaction.finalize()
//            Component.onCompleted: store.printProductStatus(status)
//            onStatusChanged: store.printProductStatus(status)
//        }
//    }

//    Column {

//        id: column
//        spacing: hmStyle.dp(5)

//        property var childItems: [headerText1, headerText2, spacer,
//                                discountText1, discountText2, discountText3,
//                                 pricesRow, purchaseButton, restoreButton]
//        function calculateHeightFromChilds(childs, spacing) {
//            var i = 0
//            var height = 0
//            for(i; i<childs.length; ++i) {
//                height += childs[i].visible ? childs[i].height : 0
//            }
//            height += (childs.length-1)*spacing
//            return height;
//        }
//        Component.onCompleted: {
//            height = Qt.binding( function() {return calculateHeightFromChilds(childItems, column.spacing)} )
//        }

//        width: 0.75*parent.width
//        anchors.centerIn: parent

//        HMText {
//            id: headerText1
//            anchors.horizontalCenter: parent.horizontalCenter
//            //: "Unlock HookahGusto" text
//            text: qsTr("unlock-hookahgusto")
//            wrapMode: Text.WordWrap
//            font.pixelSize: hmStyle.unlockHeaderFontSize
//        }

//        HMText {
//            id: headerText2
//            anchors.horizontalCenter: parent.horizontalCenter

//            //: "and get access to all sections!"
//            text: qsTr("get-access-text")
//            wrapMode: Text.WordWrap
//            font.pixelSize: hmStyle.unlockHeaderFontSize
//        }
//        Item {
//            id: spacer
//            width: parent.width
//            height: hmStyle.dp(40)
//        }

//        HMText {
//            id: discountText1
//            anchors.horizontalCenter: parent.horizontalCenter
//            text: "<font color=\"yellow\">Limited time offer!</font>"
//            wrapMode: Text.WordWrap
//            font.pixelSize: hmStyle.unlockHeaderFontSize*1.3
//            visible: utility.discountValid
//        }
//        HMText {
//            id: discountText2
//            anchors.horizontalCenter: parent.horizontalCenter
//            text: "<font color=\"yellow\">50% OFF for 30 minutes</font>"
//            wrapMode: Text.WordWrap
//            font.pixelSize: hmStyle.unlockHeaderFontSize*1.3
//            visible: utility.discountValid
//        }

//        HMText {
//            id: discountText3
//            anchors.horizontalCenter: parent.horizontalCenter
//            text: utility.discountValid ? "<font color=\"yellow\">" + utility.discountValidTime + "</font>" : "";
//            wrapMode: Text.WordWrap
//            font.pixelSize: hmStyle.unlockHeaderFontSize*1.5
//            visible: utility.discountValid
//        }


//        Row {
//            id: pricesRow
//            anchors.horizontalCenter: parent.horizontalCenter
//            width: discountText4.width + discountText5.width + spacing
//            height: discountText4.height
//            visible: utility.discountValid
//            Component.onCompleted: console.log("height:", height, "width:",width)
//            spacing: hmStyle.dp(5)

//            HMText {
//                id: discountText4
//                text: "<font color=\"yellow\">" + hookahGustoUnlockProduct_FullPrice.price + "</font>";
//                wrapMode: Text.WordWrap
//                font.pixelSize: hmStyle.unlockHeaderFontSize*1.5
//                font.strikeout: true
//                visible: utility.discountValid
//                Component.onCompleted: console.log("DISCOUNT 4 height:", height, "width:",width)
//                Layout.minimumWidth: contentWidth
//            }


//            HMText {
//                id: discountText5
//                text: "<font color=\"yellow\">" + hookahGustoUnlockProduct.price + "</font>";
//                wrapMode: Text.WordWrap
//                font.pixelSize: hmStyle.unlockHeaderFontSize*1.5
//                visible: utility.discountValid
//                Component.onCompleted: console.log("DISCOUNT 5 height:", height, "width:",width)
//                Layout.minimumWidth: contentWidth

//            }
//        }

//        HMButton {
//            id: purchaseButton
//            anchors.horizontalCenter: parent.horizontalCenter
//            //: "Purchase" button text
//            property string buyText: qsTr("share-unlock-button-text")
//            //: "Purchase for...!" button text
//            property string buyForText: qsTr("share-unlock-for-button-text") + " " + unlockProduct.price
//            text: unlockProduct.status != Product.Registered ? buyText : buyForText
//            height: hmStyle.bottomButtonHeight
//            width: parent.width
//            capitalization: Font.MixedCase
//            onClicked: unlockProduct.purchase()
//        }

//        HMButton {
//            id: restoreButton
//            anchors.horizontalCenter: parent.horizontalCenter
//            //: "Restore" button text
//            text: qsTr("share-reslotre-button-text")
//            height: hmStyle.bottomButtonHeight
//            width: parent.width
//            capitalization: Font.MixedCase
//            onClicked: store.restorePurchases()
//        }
//    }



//    HMButton {
//        id: noThanksButton
//        anchors {
//            bottom: parent.bottom
//            left: parent.left
//            right: parent.right
//            leftMargin: hmStyle.buttonMargin
//            rightMargin: hmStyle.buttonMargin
//            bottomMargin: hmStyle.buttonMargin
//        }
//        //: "No, Thanks" button text
//        text: qsTr("no-button-text")
//        height: hmStyle.bottomButtonHeight
//        capitalization: Font.MixedCase

//        onClicked: {
//            screensStack.closeScreen()
//        }
//    }

//    //-----------------------------------------------------------------------------
//}
