import QtQuick 2.2
import QtQuick.Window 2.1
import QtQuick.Controls 1.1



Item {

    property int screenWidth;
    property int screenHeight;
    property string screenSize;
    property real sizeMultiplier: 1


    Component.onCompleted: {
        //calcMultiplier();
    }

    function calcMultiplier() {
        var height = Math.max( geometry.width, geometry.height);
        var width = Math.min( geometry.width, geometry.height);

        if( diagonal >= 9 )
        {
            screenSize = "xxlarge";
            sizeMultiplier = 1.5;
        }
        else if( diagonal >= 7 )
        {
            screenSize = "xlarge";
            sizeMultiplier = 1.25;
        }
        else if ( diagonal >= 4.5 )
        {
            screenSize = "large";
            sizeMultiplier = 1.0;
        }
        else if ( diagonal >= 3 )
        {
            screenSize = "normal";
            sizeMultiplier = 0.75;
        }
        else
        {
            screenSize = "small";
            sizeMultiplier = 0.5;
        }

        if(Qt.platform.os == "windows") {
            sizeMultiplier = 1.0;
        }

        if(Qt.platform.os == "osx") {
            sizeMultiplier = 1.0;
        }

    }


    function dp(dpVal) {
        var dpi = physicalDotsPerInch;
        var px =  Math.round(dpVal * (dpi / 160.0) * sizeMultiplier );

        if(Qt.platform.os == "windows") {
            return px*2;
        }

        if(Qt.platform.os == "osx") {
            return px*2;
        }

        if(Qt.platform.os == "android") {
            return px;
        }

        if(Qt.platform.os == "ios") {
            return px;
        }
    }

    FontLoader {
        id: robotoLightFontLoader
        source: "qrc:/fonts/Roboto-Light.ttf"
    }

    FontLoader {
        id: robotoRegularFontLoader
        source: "qrc:/fonts/Roboto-Regular.ttf"
    }

    property string fontFamily:{
           if(!screenSize)
           {
               calcMultiplier();
           }

           if(Qt.platform.os === "ios" || Qt.platform.os === "osx"){
               return "Helvetica Neue Thin"
           }
           if(Qt.platform.os === "android"){
               if(screenSize === "small" || screenSize === "normal") {
                   return robotoRegularFontLoader.name
               }
               else {
                   return robotoLightFontLoader.name
               }
           }
           if(Qt.platform.os === "windows"){
               return robotoLightFontLoader.name
           }
           return ""
       }

    property var fontWeight:{
        if(Qt.platform.os === "ios" || Qt.platform.os === "osx"){
            return Font.Light
        }
        if(Qt.platform.os === "android"){
            if( utility.screenDensity == "mdpi" /*|| utility.screenDensity == "hdpi"*/ ) {
                return Font.Normal
            }
            else {
                return Font.Light
            }
        }
        if(Qt.platform.os == "windows"){
            return Font.Normal
        }
        return ""
    }


//-----------------------------------------------------------------------------

    //settings
    property int defaultCacheBuffer: 5000*2
    property int maximumFlickVelocity: 5000*2


    //global

    property int iconHeightWidth: dp(35)
    property int mainMenuIconHeightWidth: dp(50)
    property int menuIconHeightWidth: dp(100)
    property int starIconHeightWidth: dp(40)
    property int leftContentMargin: dp(10)
    property int rightContentMargin: dp(10)
    property int mainMenuItemMargin: dp(25)
    property int buttonMargin: dp(5)
    property int emptyListFontSize: dp(15)
    property real separatorOpacity: 0.2
    property color separatorColor: "#f1f1f1"
    property int mainImageHeight: dp(200)
    property int mainImageWidth: dp(413)
    property int mainScreenMargins: dp(25)
    property int mainScreenTopMargin: dp(15)

    //button
    property color buttonColor: "white"
    property int buttonBorderWidth: dp(2)
    property color buttonTextColor: "#3b2808"
    //property int buttonRadius: dp(7)
    property real buttonOpacity: 0.1
    property int buttonFontHeight: dp(20)
    property int smallButtonFontHeight: dp(15)
    property int smallButtonTopBottomMargin: dp(5)


    property int headerImageHeight: dp(150)
    property int mainCaptionHeight: dp(50);
    //242424

    //screen main
    property int elementsSpacing: dp(0);
    property int titleFontSize: dp(35)
    property int titleDespcriptionFontSize: dp(15)
    property int titleTopMargin: dp(10)

    //navigation bar
    property color navigationBarTextColor: "white";
    property int navigationBarHeight: dp(50);
    property int navigationBarFontSize: dp(20);
    property int navigationBarBackButtonSize: dp(20);


    //list item
    property int listItemSpacing: dp(15)
    property int listItemMainMenuColorBlockWidth: dp(25);
    property int listItemHeaderMainMenuTextFontSize: dp(30);
    property int mainMenuTextFontSize: dp(25);
    property int listItemHeaderMenuTextFontSize: dp(20);
    property color listItemMainMenuTextColor: "black";
    property int listItemMainMenuDescriptionFontSize: dp(15);
    property int listItemMenuDescriptionFontSize: dp(15);
    property color listItemMainMenuDescriptionTextColor: "darkgrey";
    property int listItemHeaderMenuHeight: dp(75);
    property int listItemMenuHeight: dp(150);
    property int listItemRightArrowWidth: dp(25);
    property color listItemSeparatorColor: "#f1f1f1"
    property int listItemSeparatorHeight: dp(1)
    property int listItemImageBorderWidth: dp(3);
    property int listItemMainMenuDescriptionMaring: dp(5);
    property real listItemDefaultDarkOpacity: 0.8
    property int rateMixFontSize: dp(15)
    property int splashScreenFontSize: dp(18)


    //mix control
    property int mixIngredientHeight: dp(70);
    property int mixIngredientLineFontSize: dp(15);
    property int mixIngredientFlavorFontSize: dp(20);
    property int mixIngredientColorBlockWidth: dp(4);
    property int mixIngredientAmountFontSize: dp(21);
    property int amountTextWidth: dp(50)
    property int mixTopBottomMargin: dp(10)
    property int circleHeight: dp(60)
    property int flavorCircleItemHeight: dp(40)
    property int flavorCircleHeight: dp(15)
    property int flavorCircleSelectedHeight: dp(20)
    property color flavorCircleBorderColor: Qt.rgba(0, 0, 0, 0.3) //Qt.rgba(76, 77, 71, 0.5)
    property color flavorCircleBorderSelectedColor: Qt.rgba(255, 255, 255, 0.3) //Qt.rgba(76, 77, 71, 0.5)
    property int circleThickness: dp(3)
    property int iconCircleThickness: dp(2)
    property int circleSelectedThickness: dp(12)

    //mix screen
    property int ratingControlBottomMargin: dp(125)

    //mixes list
    property int mixesListLeftRightMargin: dp(5);
    property int mixesListSeparatorHeight: dp(5);
    property int mixesListRatingHeight: dp(20)
    property int mixesListMixTopBottomMargin: dp(5)

    //
    property int bottomButtonHeight: dp(50);
    property int addMixButtonHeightWidth: dp(100);

    //brands list
    property int menuItemLeftRightMargin: dp(12)

    //listitemflavor
    property int listItemFlavorHeight: dp(60)
    property int listItemFlavorFontSize: dp(18)
    property int listItemFlavorColorBlockWidth: dp(7)
    property int listItemFlavorColorBlockSelectedWidth: dp(12)
    property int listItemFlavorLeftMargin: dp(15)
    property int listItemFlavorColorBlockTopBottomMargin: dp(3)
    property int listItemFlavorSeparatorHeight: dp(0)
    property color listItemFlavorSeparatorColor: "lightgrey"

    //filter screen
    property color filterScreenBackgroundColor: "#201a26"
    property int filterCaptionFontSize: dp(15)
    property int listItemHeaderMenuHeightInFilter: dp(60)
    property int listItemFlavorHeightInFilter: dp(50)
    property int iconHeightWidthInFilter: dp(25)
    property int listItemHeaderMenuInFilterTextFontSize: dp(22);
    property int listItemFlavorInFilterFontSize: dp(15)
    property int leftContentMarginInFilter: dp(5)
    property int filterContentWidth: 0.7*screenWidth
    property int filterCloseBarWidth: 0.1*screenWidth
    property int filterFlavorsTextWidth: filterContentWidth - flavorCircleItemHeight

    //rate screen
    property int rateHeaderFontSize: dp(22)
    property int unlockHeaderFontSize: dp(18)

    //tutorials screen
    property int tutorialsFontSize: dp(16)
    property int tutorialsHeaderSize: dp(30)
    property int tutorialsSubHeaderSize: dp(22)
    property int tutorialsLeftRightMargin: dp(15)
    property int tutorialsBottomMargin: dp(50)
    property int tutorialsSpacing: dp(20)
    property int tutorialsImageHeight: dp(120)
    property int tutorialsImageDescriptionFontSize: dp(18)
    property int tutorialsImageSourceFontSize: dp(14)
    property int languageButtonHeight: dp(40);
    property int languageButtonFontSize: dp(20);
    property int languageWarningFontSize: dp(15)

//-----------------------------------------------------------------------------

    property string imageMain: utility.imagePath("Main_image.png")
    property string imageBackground: utility.imagePath("Back.jpg")
    property string imageNavBarBackground: utility.imagePath("Nav_bar.png")
    property string imageNavBarBack: utility.imagePath("Backwards.png");
//    property string imageNavBarAdd: utility.imagePath("Add_nav.png");
//    property string imageNavBarDelete: utility.imagePath("Delete_nav.png");
    property string imageMyTobaccoMenu: utility.imagePath("My_tob.png");
    property string imageMixesMenu: utility.imagePath("Mixes.png");
    property string imageVkMenu: utility.imagePath("vk_main_screen_icon.png");
    property string imageTutorialsMenu: utility.imagePath("Tuts.png");
    property string imageNewsMenu: utility.imagePath("news.png");
    property string imageAddButton: utility.imagePath("Add.png");
    property string imageAddButtonPressed: utility.imagePath("Add_press.png");
    property string imageVioletButton: utility.imagePath("Social.png");
    property string imageVioletButtonPressed: utility.imagePath("Social_press.png");
    property string imageButton: utility.imagePath("Apply.png");
    property string imagePressedButton: utility.imagePath("Apply_press.png");
    property string imageRemoveFlavorsButton: utility.imagePath("Delete.png");
    property string imageRemoveFlavorsButtonPressed: utility.imagePath("Delete_press.png");

    property string imageShareVkButton: utility.imagePath("vk.png");
    property string imageShareFbButton: utility.imagePath("fb.png");
    property string imageShareTwButton: utility.imagePath("tw.png");
    property string imageShareInstButton: utility.imagePath("inst.png");
    property string imageShareVkPressedButton: utility.imagePath("vk_press.png");
    property string imageShareFbPressedButton: utility.imagePath("fb_press.png");
    property string imageShareTwPressedButton: utility.imagePath("tw_press.png");
    property string imageShareInstPressedButton: utility.imagePath("inst_press.png");

    property string imageArrowUp: utility.imagePath("Close_list.png");
    property string imageArrowDown: utility.imagePath("Open_list.png");
    property string imageStarOn: utility.imagePath("Rate_onemix_y.png");
    property string imageStarOff: utility.imagePath("Rate_onemix_b.png");

    property string imageFilterButton: utility.imagePath("Search_ic.png");
    property string addButtonIcon: utility.imagePath("Add_ic_over_but.png");
    property string searchButtonIcon: utility.imagePath("Find_mix_ic_over_but.png");
    property string deleteButtonIcon: utility.imagePath("Del_ic_over_but.png");
    property string shareButtonIcon: utility.imagePath("Social_ic_over_but.png");
    property string addFavoriteButtonIcon: utility.imagePath("Fav_ic_over_but.png");
    property string removeFavoriteButtonIcon: utility.imagePath("Remove_fav_ic_over_but.png");
    property string imageFavButtonDivider: utility.imagePath("Fav_but_div.png");
    property string imageSocButtonDivider: utility.imagePath("Social_but_div.png");

    property string imageHookahGustoAbout: "qrc:/images/hgicon.png"
    property string imageFbSmallIcon: "qrc:/images/fbSmallIcon.png"
    property string imageVkSmallIcon: "qrc:/images/vkSmallIcon.png"
    property string imageTwSmallIcon: "qrc:/images/twSmallIcon.png"
    property string imageInstSmallIcon: "qrc:/images/instSmallIcon.png"
    property int imageHookahGustoAboutHeight: dp(200)
    property int imageSmallSocialIconsHeight: dp(35)
    property int imageBigSocialIconsHeight: dp(50)
    property int aboutTextSize1: dp(22)
    property int aboutTextSize2: dp(14)
    property int aboutTextSize3: dp(18)

    property string imageDoobaccoAbout: "qrc:/images/doobacco.png"
    property string imageNargiliaAbout: "qrc:/images/nargilia.png"
    property string imageSarkisAbout: "qrc:/images/sarkis.png"
    property string imageHookahBossAbout: "qrc:/images/hookahboss.png"
    property int imageAboutHeight: dp(150)
    property int versionInfoFontSize: dp(10)
    property int loadingIconHeight: dp(50)
}

