import QtQuick 2.2
import QtQuick.Controls 1.1
import HookahMixesModels 1.0
import QtQuick.Window 2.1
import QtQuick.Layouts 1.1
import Enginio 1.0

//Root element
Item {
    id: root

    //property bool languageChangeRequested: false


    function onQmlBecomeVisible() {        
        var mixId = utility.calledMixId();
        if(mixId != -1) {
            screensStack.openScreen(Qt.resolvedUrl("ScreenMixDetails.qml"), {"mixId": mixId, immediate: true });
        }
    }

    Component.onCompleted: {
        if(Qt.platform.os == "windows" || Qt.platform.os == "osx") {
            width = 480
            height = 720
        }

        utility.qmlBecomeVisible.connect(onQmlBecomeVisible);
    }

    //init style
    Style {
        id:hmStyle
        screenWidth: root.width
        screenHeight: root.height
    }

    Image {
        id: backImage
        anchors.fill: parent
        source: screensStack.currentItem ? screensStack.currentItem.background : ""
    }


        //titlebar
    NavigationBar {
        id: navbar
        title: screensStack.currentItem ? screensStack.currentItem.screenTitle : ""
        backButtonVisible: screensStack.depth > 1
        onBackPressed: {
            backPressedProcessing(null);
        }
        //z: 1 //make it topmost
        anchors {
            left: parent.left
            right: parent.right
            top: parent.top
        }

        function update() {
            if(screensStack.currentItem) {
                if(screensStack.currentItem.navBarButtons) {
                    navigationButtonsModel = screensStack.currentItem.navBarButtons
                }
                else {
                    navigationButtonsModel = null
                }
            }
        }
    }


    //stackview with all screens
    StackView {
        id: screensStack

        property string test: "uninitialized"

        function openScreen( screenItem, properties ) {
            currentItem.visible = false;
            push(screenItem, properties)
        }
        function closeScreen() {
            currentItem.visible = false;
            pop({immediate: true});
        }

        anchors {
            left: parent.left
            right: parent.right
            bottom: parent.bottom
            top: navbar.bottom
        }

        initialItem: Qt.resolvedUrl("ScreenMain.qml")

        onCurrentItemChanged: {
            if(currentItem != null) {
                navbar.update();
                currentItem.update()
                //Log screen changing:
                if(currentItem.screenName) {
                    console.log("utility.googleAnalyticsHitScreen()", currentItem.screenName)
                    utility.googleAnalyticsHitScreen(currentItem.screenName)
                }
            }
        }
    }

    //popup filter in the right part of the screen
    HMFilterControl {
        id: filterControl

        anchors.top: parent.top
        anchors.bottom: parent.bottom
        x: 0
        width: visible ? parent.width : 0
        visible: false
        //: "Filter mixes" caption on filter control
        captionText: qsTr("filter-mixes-control-caption")
    }

    focus: true
    Keys.onBackPressed: {
        backPressedProcessing(event)
    }

    function backPressedProcessing(event) {
        if(screensStack.depth > 1) {
            //close filter control if opened
            if(filterControl.visible)
            {
                filterControl.hide();
            }
            //process backpress by screen if possible
            else if(!screensStack.currentItem.processBackPress())
            {
                screensStack.closeScreen();
            }
        }
        else {
            if(event) {
                event.accepted = false;
            }
        }
    }


    function userWorksWithAppMaybeShowHimRateScreen() {

        settings.logProgramUsage();
        if(settings.useCount() >= 3 && settings.canAskToRate()) {
            screensStack.openScreen(Qt.resolvedUrl("ScreenRate.qml"));
        }
    }

    ScreenSplash {
        visible: utility.splashVisible
        anchors.fill: parent
    }
}

